% Load values from .csv 
% Take certain value, fit them and then use the new values to normalize the
% spectrum 
% Line 28 : put the value of the repetitive tau 
clear all
close all 
tic
p = LoadPath()                                                             ;
%%%%%%%%
repetitivetau = 100                                                        ; % Put the value of the repetitive tau (ms)
factor        = 1.1923                                                          ; % factor for adjustement if the repetitive was not the max. always start with 1. max(new.fnorm)= new factor
%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%% Sequence %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

type_experiment{1} = "SEPP"                                                ;
type_experiment{2} = "SEPP-SPINEPT"                                        ;
type_experiment{3} = "SEPP-SPINEPT_magnitude"                              ;

Type               = type_experiment{3}                                    ;

File_name          = "20230920_2_13C_pyr_7_exp326_-24.09_(2)_267K_dc"      ;
%% loading data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
switch Type
    
    case "SEPP"
data_in       = load("P:\user_permanent\Charbel_Assaf\0_NMR_Data\1_NMR400\20230828_2_13C_Pyr_5\"+File_name+".txt",'-ASCII');        

data.tau      = data_in(:,1)                                               ;
data.y        = data_in(:,2)                                               ;

    
    case "SEPP-SPINEPT"
data_in       = load("\\uni-kiel.de\files\rad\public\section\own_contributions\papers\2023_CA_AP_JCH\Data\Figure_S12_other_complexes\"+File_name+".txt",'-ASCII'); 

data.tau      = data_in(:,1)                                               ;
data.y_left   = data_in(:,2)                                               ;
data.y_right  = data_in(:,3)                                               ;
data.y        = data.y_left-data.y_right                                   ;
 
    case "SEPP-SPINEPT_magnitude"
data_in       = load("P:\user_permanent\Charbel_Assaf\0_NMR_Data\1_NMR400\20230829_1_13C_Pyr_5\"+File_name+".txt",'-ASCII'); 

data.tau      = data_in(:,1)                                               ;
data.y        = data_in(:,2)                                               ;

end

data.ID       = (0:length(data.tau)-1)'                                    ;
data.norm     = data.y ./ max(data.y)                                      ; % normalized by the maximum of the value
data

%% plotting SABRE signal of the experiment in order of acquisition %%%%%%%%
figure
set(gcf,'color','w')                                                       ;
plot(data.ID, data.y, 'x')                                                 ;
xlabel('ID')                                                               ;
ylabel('Amplitude')                                                        ;
title('First signal')                                                      ;

% out = [data.ID, data.y];
% save("first signal.csv","out",'-ASCII')
%% plotting SABRE signal of the experiment %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure; 
set(gcf,'color','w')                                                       ;
subplot(2,2,1)                                                             ;
plot(data.tau, data.y, 'x')                                                ;
xlabel('Tau (ms)')                                                         ;
ylabel('Amplitude')                                                        ;
title('First signal')                                                      ;
grid on 

% %% Having only values of the highest signal %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
filter       = data.tau==repetitivetau                                     ;  
cal.ID       = data.ID(filter)                                             ;
cal.y        = data.y(filter)                                              ;
cal.tau      = data.tau(filter)                                            ;
%cal          = poly2_fit_cal(cal)                                         ;
cal          = poly1_fit_cal(cal)                                          ;
cal.MeanMaxV = sum(cal.y(:,1))/length(cal.y)                               ; % mean amplitude of all repetitive tau
cal
%  plotting maximum amplitudes 
subplot(2,2,2)                                                             ;
plot(cal.ID, cal.y, 'x')                                                   ;
xlabel('ID')                                                               ;
ylabel('Amplitude')                                                        ;
title(sprintf('Maximum Integrals (tau = %.3fms)',repetitivetau))           ; 
grid on 

% out = [cal.ID, cal.y];
% save("Max integrals.csv","out",'-ASCII')
%% fitting the maximum values %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
data.corr    = poly1(cal.fit.constant,data.ID)                             ; % max value fitted for each tau
data.y_corr  = data.y ./(factor*data.corr)                                          ; % normalized by the max of the fitted value of each tau  %%%% ad the factor (1.17.*data.corr)

%% plotting normalized fitting maximum amplitudes %%%%%%%%%%%%%%%%%%%%%%%%%
subplot(2,2,3)                                                             ;
plot(data.tau, data.y_corr, 'x')                                           ;
xlabel('Tau (ms)')                                                         ;
ylabel('Amplitude')                                                        ;
title('Normalized after fitting');
grid on 

%%plotting fitting + maximum amplitudes %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
subplot(2,2,4)                                                             ;
plot(data.ID,data.corr,'r','LineWidth',2)                                  ;
hold on 
plot(cal.ID, cal.y,'O')                                                    ;
xlabel('ID')                                                               ;
ylabel('Max Amplitude')                                                    ;
title('fitting Max Integrals')                                             ;
grid on 
% out = [data.ID, data.corr];
% save("fitting Max integrals.csv","out",'-ASCII')
%% All amplitude without the maximum %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
not=(data.tau~=repetitivetau)                                              ;
new.tau     = data.tau(not)                                                ;
new.ID      = data.ID(not)                                                 ;
new.y       = data.y(not)                                                  ;
new.ynorm   = new.y/max(new.y)                                             ;
new.norm    = data.norm(not)                                               ; % normalized by the maximum of the amplitudes 
new.fnorm   = data.y_corr(not)                                             ; % normalized by the fitted value of the maximum amplitudes of each tau

%% Insert the repetitive tau into new.tau without adjustment %%%%%%%%%%%%%%
s = [new.tau,new.ynorm]                                                    ; % new.y 
cal.MeanMaxV  = cal.MeanMaxV/max(new.y)                                    ; % cal.MeanMaxV/max(data.corr);%
s((end+1), :) = [repetitivetau ;cal.MeanMaxV ]                             ;
       
[SortedtauOld,I] = sort(s(:,1))                                            ; % same as Sortedtau all tau used in the sequence even with the repetitive tau
y = s(:,2)                                                                 ;
Sorted_norm = y(I)                                                         ; % all y values normalize by the maximum without adjustment 

PAPER = [SortedtauOld , Sorted_norm]                                       ; % Taking the values for the PAPER 
%csvwrite('\\uni-kiel.de\files\rad\public\section\own_contributions\papers\2023_CA_AP_JCH\Data\Figure_S12_other_complexes\'+File_name+'_adjusted.csv',PAPER)% SEPP_exp12_12ms   SEPP_SPINEPT_exp22_168.5ppm
%% Insert the repetitive tau into new.tau %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
s = [new.tau,new.fnorm]                                                    ; % new.fnorm  new.y
%cal.MeanMaxV  = 1                                                          ; % cal.MeanMaxV/max(data.corr);%
s((end+1), :) = [repetitivetau ;cal.MeanMaxV ]                             ;
       
[Sortedtau,I] = sort(s(:,1))                                               ;
y = s(:,2)                                                                 ;
Sorted_f.norm = y(I)                                                       ;

%% plotting first results and adjusted results %%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure
set(gcf,'color','w')                                                       ;
subplot(1,2,1)                                                             ; 
plot(data.tau, data.norm, 'O')                                             ;
hold on
plot(data.tau, data.y_corr,'X')                                            ; %data.y_corr
xlabel('Tau (ms)')                                                         ;
ylabel('Amplitude')                                                        ;
legend('Initial signal','signal after adjustment')                         ;
grid on 

subplot(1,2,2)                                                             ;
plot(new.tau, new.norm, 'r','LineWidth',2)                                 ;
hold on
plot(Sortedtau, Sorted_f.norm, 'b','LineWidth',2)                          ;
xlabel('Tau (ms)')                                                         ;
ylabel('Amplitude')                                                        ;
legend('Initial signal','signal after adjustment')                         ;
grid on 

%% Plotting Max Integrals normalize by the fitting values %%%%%%%%%%%%%%%%%
figure
cal.Maxfitted = data.y_corr(filter)                                        ;
plot(cal.ID, cal.Maxfitted, 'x')                                           ;
xlabel('ID')                                                               ;
ylabel('Max Integral')                                                     ;
title('Max Integral Normalized after fitting')                             ;
hold on       
plot(new.ID, new.fnorm)                                                    ;
% out = [cal.ID, cal.Maxfitted];
% save("Max Integral Normalized after fitting.csv","out",'-ASCII')
% out = [new.ID, new.fnorm];
% save("Integrals after adjustment.csv","out",'-ASCII')
%% save data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 out = [Sortedtau, Sorted_f.norm]                                          ;
% csvwrite("P:\user_permanent\Charbel_Assaf\0_NMR_Data\1_NMR400\20230829_1_13C_Pyr_5\"+File_name+"_adjusted.csv",out)
%%
factor = max(new.fnorm)
toc