%% loading data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
tic
clear all
close all

type_Figure{1} = "SABRE-ESOTHERIC"                                         ;
type_Figure{2} = "SEPP"                                                    ;

Type = type_Figure{2}                                                      ;

switch Type
    
    case "SABRE-ESOTHERIC"
    %% Load data of phINEPTplus pulse sequences
    ex.experiment = "G:\.shortcut-targets-by-id\1-XRbGQ-3Z93DOptEdwjJ6iviB1PC2QTI\2P_PHIP_and_more\7_15N_SABRE_ESOTHERIC_INEPT\expdata\Paper\"  ; 
    data_in       = load(ex.experiment+'20230110_CA_Pyridine_ESOTHERIC_INEPT_exp5-10.txt','-ascii')  ; % 20230118_CA_ACETONITRILE3_INEPT_exp6-13 20230110_CA_Pyridine_ESOTHERIC_INEPT_exp5-10  20230125_CA_NICOTINAMIDE_INEPT_exp6-15.ser
    tau1          = data_in (2:end, 1)                                     ;                           % 20230128_CA_Pyridine4amine_INEPT
    tau2          = data_in (1, 2:end)                                     ;
    [X1,Y1]       = meshgrid(tau2,tau1)                                    ;
    Z1            = data_in (2:end , 2:end)                                ;


    % Load data of ESOTHERIC pulse sequences
    data_in       = load(ex.experiment+'20230110_CA_Pyridine_ESOTHERIC_INEPT_exp21-27.txt','-ascii')  ; % 20230118_CA_ACETONITRILE3_ESOTHERIC_exp200-207  20230110_CA_Pyridine_ESOTHERIC_INEPT_exp21-27  20230125_CA_NICOTINAMIDE_ESOTHERIC_exp21-27
    tau11         = data_in (2:end, 1)                                     ;                            % 20230128_CA_Pyridine4amine_ESOTHERIC
    tau22         = data_in (1, 2:end)                                     ;
    [X2,Y2]       = meshgrid(tau22,tau11)                                  ;
    Z2            = data_in (2:end , 2:end)                                ;

    MAX           = max([max(max(Z1)) max(max(Z2))])                       ;
    Z1            = Z1/MAX                                                 ;
    Z2            = Z2/MAX                                                 ;


    levels        = 0:0.05:1                                               ; 
    figure('Name','MAX Polarisation Transfer','Color','white','Position',[700 0 750 1700],'DefaultAxesFontSize',40)
    colormap("jet")                                                        ;
    ax            = axes('Box','on')                                       ; 
    tiledlayout(2,1)                                                       ;  

    nexttile
    contourf(X1,Y1,Z1,levels,'edgecolor','none')
    axis([min(tau2),max(tau2),min(tau1),max(tau1)])                        ;
    caxis([0,1])                                                           ;
    b             = gca                                                    ;
    xticks(min(tau2):1:max(tau2))   
    yticks(min(tau1):1:max(tau1))  
    b.YAxis.TickLength = [0.035 0.2]                                       ;
    b.XAxis.TickLength = [0.035 0.2]                                       ;
    b.TickDir          = 'out'                                             ;
    b.XAxis.LineWidth  = 2                                                 ;
    b.YAxis.LineWidth  = 2                                                 ; 
    xtickangle(0)

    nexttile
    contourf(X2,Y2,Z2,levels,'edgecolor','none')
    axis([min(tau22),max(tau22),min(tau11),max(tau11),0,1])                ;
    caxis([0,1])                                                           ;
    d=gca                                                                  ;
    xticks(min(tau22):1:max(tau22)) 
    yticks(min(tau11):1:max(tau11))
    d.YAxis.TickLength = [0.035 0.2]                                       ;
    d.XAxis.TickLength = [0.035 0.2]                                       ;
    d.TickDir = 'out'                                                      ;
    d.XAxis.LineWidth  = 2                                                 ;
    d.YAxis.LineWidth  = 2                                                 ;
    xtickangle(0)
    
    case "SEPP"

    ex.experiment = "C:\CharbelAssaf_Files\0_NMR_Data\1_NMR400\20230615_CA_Pyruvate_SEPPINEPT5\"  ; 
    data_in       = load(ex.experiment+'SEPP.txt','-ascii')                ; 
    tau1          = data_in (2:end, 1)                                     ;                                     
    tau2          = data_in (1, 2:end)                                     ;
    [X1,Y1]       = meshgrid(tau2,tau1)                                    ;
    Z             = -data_in (2:end , 2:end)                               ;
    Z             = Z/(max(abs(max(abs(Z)))))                              ;

    [maxValue, linearIndex] = max(Z(:))                                    ;
    [row, column]           = ind2sub(size(Z), linearIndex)                ;
    disp(['Maximum value: ' num2str(maxValue)])                            ;
    disp(['Coordinates: (' num2str(row) ', ' num2str(column) ')'])         ;
    
    levels        = -1:0.05:1                                              ; 
    figure('Name','MAX Polarisation Transfer','Color','white','Position',[300 0 1000 400],'DefaultAxesFontSize',20)
    colormap("parula")                                                     ;
    ax            = axes('Box','on')                                       ; 
    tiledlayout(2,1)                                                       ;
    
    contourf(X1,Y1,Z,levels,'edgecolor','none')
    axis([min(tau2),max(tau2),min(tau1),max(tau1)])                        ;
    caxis([-1,1])                                                          ;
    b                     =  gca                                           ;
    xticks(min(tau2):5:max(tau2))   
    yticks(min(tau1):2.5:max(tau1))   
    b.YAxis.TickLength    = [0.005 0.005]                                  ;
    b.XAxis.TickLength    = [0.005 0.005]                                  ;
    b.TickDir             = 'in'                                           ;
    b.XAxis.LineWidth     = 2                                              ;
    b.YAxis.LineWidth     = 2                                              ; 
    %xlabel('tau (ms)')
    %ylabel('delta (ms)')
    xtickangle(0)
    %title(sprintf('The highest polarization is at (tau = %i ms, delta = %i ms)',tau2(column),tau1(row))); 

end 
a = colorbar('Ticks',[-1,-0.8,-0.6,-0.4,-0.2,0,0.2,0.4,0.6,0.8,1],'LineWidth',2) ;

%saveas(gcf,'P:\section\own_contributions\papers\2023_CA_AP_SABRE\figure\Figure 1_ESOTHERIC&INEPTplus\Pyridine_ESO_INEPT_image2D.png') 


%% figure for colorbar
% figure('Position',[700 0 850 1700]);
% colormap("jet");
% a = colorbar('Ticks',[0,0.2,0.4,0.6,0.8,1],'LineWidth',1.5,'TickDirection','out','position',[0.7544    0.175    0.035    0.5275],'Fontsize',28) ;


toc
