%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all; %clear all and delete all previous data
LoadPath();
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%  Spectroscopy(N=3), Classical Transition approach %%%%%%%%%%%%
tic
System_ID=37;% EFP-38, Eth-Pyruvate-d6-spin2-40, Eth-Acetate-d3-spin2-37
System=Load_System_Name(System_ID);
ex = Load_System(System);
Frequency = 2.430581668777235e+07;
ex.B0=Frequency/(ex.S.gamma{1}/2/pi);
%ex.B0=0.55;%0.55;% Tesla
p90=33e-6;
p180=p90*2;
p45=p90/2;
err=1;
ppmrf=0e-6;
tau=10*1e-3; 
v1=1/(4*p90);
ttotal = 4;

SOTs{1}="OPE-45-CPMG-Rn";
SOTs{2}="OPE-45-CPMG-CPRn";

SOT.name=SOTs{1};

H0=2*pi*HZJij(ex.S,ex.PPM,ex.J,ex.B0,"full");
[Q, E]=eig(full(H0));
req=DensityMatrix('100%_SingletSpinOrder',ex.S,ex.n1,ex.n2);%;%initial state
req=req.RemoveCoherences(Q);
 
H1_0=2*pi*HZJij_RF1(ex.S,ex.PPM,ex.J,ex.B0,0,ppmrf,"X",ex.eH);
H1_X=2*pi*HZJij_RF1(ex.S,ex.PPM,ex.J,ex.B0,v1,ppmrf,"X",ex.eH);
H1_Y=2*pi*HZJij_RF1(ex.S,ex.PPM,ex.J,ex.B0,v1,ppmrf,"Y",ex.eH);
[TE,nechos,out]=OPE_CPMG(SOT,req,tau,ttotal,H0,H1_X,H1_Y,ex.SOs,p45*err,p90*err,p180*err);

sim.name=SOT.name;
sim.System=System;
sim.n=nechos;
sim.B0=ex.B0;
sim.p90=p90;
sim.p180=p180;
sim.p45=p45;
sim.p_err=err;
sim.ppmrf=ppmrf;
sim.v1=v1;
sim.TE=TE*1e3;
sim.X{1}=out(:,1);
sim.X{2}=out(:,2);
sim.Y{1}=out(:,3);
sim.Y{2}=out(:,4);
sim.X12=(sim.X{1}+sim.X{2})/2;
sim.Y12=(sim.Y{1}+sim.Y{2})/2;

save('out\sim_'+sim.name+num2str(sim.n)+'_'+sim.System+'.mat','sim');

plot_kinetics(sim)

toc
%%%%% finish   Spectroscopy(N=3), Classical Transition approach %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function plot_kinetics(sim)
    figure('Name','Spectrum','Color','white','NumberTitle','off');
    subplot(2,1,1);
    plot(sim.TE,sim.X{1},'Color','blue','LineWidth',1,'DisplayName','Z OPE-45 Kinetics');
    hold on
    plot(sim.TE,sim.X{2},'Color','red','LineWidth',1,'DisplayName','Z OPE-45 Kinetics');
    plot(sim.TE,sim.X12,'Color','green','LineWidth',1,'DisplayName','Z OPE-45 Kinetics');
    ylabel('Z magnetization a.u.');
    legend(["H1X","H2X","(H1X+H2X)/2"])
    title(sim.name+" for "+sim.System);

    subplot(2,1,2);
    plot(sim.TE,sim.Y{1},'Color','black','LineWidth',1,'DisplayName','Z OPE-45 Kinetics');
    hold on
    plot(sim.TE,sim.Y{2},'Color','cyan','LineWidth',2,'DisplayName','Z OPE-45 Kinetics');
    plot(sim.TE,sim.Y12,'Color','magenta','LineWidth',2,'DisplayName','Z OPE-45 Kinetics');
    legend(["H1Y","H2Y","(H1Y+H2Y)/2"])
    xlabel('TE [ms]');
    ylabel('Z magnetization a.u.');
end

function [TE, n, out]=OPE_CPMG(SOT,rin,tau,ttotal,H0,H1_X,H1_Y,SOs,p45,p90,p180)
    n = floor(ttotal / (2*tau));
    TE = (1:n)*2*tau;
    t_evol=tau;
    out=zeros(n,length(SOs));
    [t,A,r0]=rin.EvolutionConstH(H1_Y,p45,[]); %rotation             
    r1=r0;
    switch SOT.name
        case "OPE-45-CPMG-Rn"                                                                       
            for in=1:n
                [t,A,r1]=r1.EvolutionConstH(H0,t_evol,[]);  

                [t,A,r1]=r1.EvolutionConstH(H1_Y,p180,[]); %rotation                

                [t,A,r1]=r1.EvolutionConstH(H0,t_evol,[]);        
                out(in,:)=real(r1.Amplitudes(SOs));
            end 
        
        case "OPE-45-CPMG-CPRn"        
            for in=1:n
                [t,A,r1]=r1.EvolutionConstH(H0,t_evol,[]);  
                
                [t,A,r1]=r1.EvolutionConstH(H1_X,p90,[]); %rotation 
                [t,A,r1]=r1.EvolutionConstH(H1_Y,p180,[]); %rotation
                [t,A,r1]=r1.EvolutionConstH(H1_X,p90,[]); %rotation 
                
                [t,A,r1]=r1.EvolutionConstH(H0,t_evol,[]); 
                out(in,:)=real(r1.Amplitudes(SOs));
            end                                                                          
    end                                      
end



