clear all
close all 
tic
p = LoadPath('CA')                                                             ;


%%
%%%%%%%%%%%%%%%%%%%%%% Load all data  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Folder         = "IrHH_data\kd_IrHH_pyr_[1]\"                              ;

Files{1}       = "kd_IrHH_Ha_pyr_97mM_[1].txt"                            ;
Files{2}       = "kd_IrHH_Hb_pyr_97mM_[1].txt"                            ;


[xdata,ydata, data_lengths]  = combinealldata(Folder,Files)                ;

%%
%%%%%%%%%%%%%% Fitting all combined data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initial parameter guesses
initial_params = [0.4,   1,  ...
                  1,   0.8,  ...
                  0.8,   1.2,    ]                                         ;
              
MHa1 = 1    ;   MHb1 = ydata(30)       ;   MH21 = 0                        ;
MHa2 = 1    ;   MHb2 = ydata(117)      ;   MH22 = MH21                     ;

%%%%%%%%%%%%%% Define the fitting function %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fitting_function = @(params, x) Fit_CA_2_SEPP_SABRE_nonuniform( MHa1, MHb1,   MH21, MHa2,   MHb2, MH22, ...
                                                                 params(1),    params(2),     ...
                                                                 params(3),    params(4),     ...
                                                                 params(5),    params(6), data_lengths, x   ); % (MHa1,MHb1,MH21,MHa2,MHb2,MH22,kd,kex,kaprime,RHa,RHb,RH2,L, x)

%%%%%%%%%%%%%% Perform the fitting using nlinfit %%%%%%%%%%%%%%%%%%%%%%%%%%
[beta1,R,J,CovB] = nlinfit(xdata, ydata, fitting_function, initial_params) ;

ysim             = fitting_function(beta1,xdata)                           ;
SE               = sqrt(diag(CovB))                                        ;

%%%%%%%%%%%%%%%%%%% Display the fitted parameters %%%%%%%%%%%%%%%%%%%%%%%%%
kd                = beta1(1)                                               ;
kex               = beta1(2)                                               ;
kaprime           = beta1(3)                                               ;
RHa               = beta1(4)                                               ;
RHb               = beta1(5)                                               ;
RH2               = beta1(6)                                               ;

disp('Fitted Parameters:')                                                 ;
fprintf('kd  = %.3f ± %.3f s^-1 \n\r',[kd,SE(1)])                          ;
fprintf('kex = %.3f ± %.3f s^-1 \n\r',[kex,SE(2)])                         ;
fprintf('kaprime = %.3f ± %.3f s^-1 \n\r',[kaprime,SE(3)])                 ;
fprintf('RH2 = %.3f ± %.3f s^-1 \n\r',[RH2,SE(6)])                         ;
fprintf('RHa = %.3f ± %.3f s^-1 \n\r',[RHa,SE(4)])                         ;
fprintf('RHb = %.3f ± %.3f s^-1 \n\r',[RHb,SE(5)])                         ;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% fprintf("start to fit with IrHH->H2 Matrix model \n")
%             MHa = data.Ha(1) ;        MHb = data.Hb(1);   MH2 = data.H2(1)                                                           ; % 
%             data.r                        = zeros(size(data.dmix))                                                                   ; %     
%             Nt                            = length(data.dmix)                                                                        ;
%             xdata_fit                     = reshape(data.dmix*[1,1,1],3*Nt,1)                                                        ;
%             ydata                         = [data.Ha; data.Hb; data.H2 ]                                                             ; % the three sets of ydata values
%             I                             = [ 0.04, 2.3, 1.29, 0.05, 1.53,0.04, 2.3, 1.29, 0.05, 1.53, 1, 1]                         ; %  initial parameters  kd1,kd2,kd3, kaprime1,kaprime2,kaprime3, kex1, kex2, R1,R2,R3,Rf
%             
%             % Initial guess                                                                (MH1a, MH1b, MH2a, MH2b, MH3ab, MH2,kd1,kd2,kd3, kaprime1,kaprime2,kaprime3, kex1, kex2, R1,R2,R3,Rf,x)   
%             fitfunc                       = @(i_params, x)SABRE_hydrogen_exchange_Lmatrix_6(MH1a, MH1b, MH2a, MH2b, MH3ab, MH2, I(1), I(2), I(3), I(4), I(5), I(6), I(7), I(8), I(9), I(10), I(11), I(12), x)  ;
%             y0                            = SABRE_hydrogen_exchange_Lmatrix_6(MH1a, MH1b, MH2a, MH2b, MH3ab, MH2, I(1), I(2), I(3), I(4), I(5), I(6), I(7), I(8), I(9), I(10), I(11), I(12), xdata_fit )       ;
%             semilogx(data.dmix, data.Ha, 'o', data.dmix, data.Hb, 'o',data.dmix, data.H2, 'o',data.dmix,reshape(y0,Nt,3))            ;                                                                                                             
%             title("initial guess")
%             [beta1,R,J,CovB]              = nlinfit(xdata_fit,ydata,fitfunc, i_params)                                               ;
%             coefficients_standard_errors  = sqrt(diag(CovB))                                                                         ;
%             CSE                           = coefficients_standard_errors                                                             ; 
%             fprintf("results: \n")                                                                                                   ;
%             fprintf("Model IrHH->H0 MatrixK has kd = %.3f ± %.3f s-1,kex = %.3f ± %.3f s-1, RH2 = %.3f ± %.3f s-1 , kaprime = %.3f ± %.3f s-1, RHab = %.3f ± %.3f s-1 \n",beta1(1),CSE(1),beta1(2),CSE(2),beta1(3),CSE(3),beta1(4),CSE(4),beta1(5),CSE(5))

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 
 
%%%%%%%%%%%%%%%%%% Plotting %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
plotNkinetics_loc(2,xdata,ydata,xdata,ysim,data_lengths)                   ;
%plotNkinetics_loc(2,xdata,ydata,xdata,ysim2,data_lengths)                  ;


%%%%%%%%%%%% Increasing the number of the fitting points %%%%%%%%%%%%%%%%%%


x_fit                     = logspace(log10(min(xdata)),log10(max(xdata)),100)' ;
x_fit_fit                 = reshape(x_fit*[1,1,1,1,1,1],6*length(x_fit),1)     ;
data_lengths              = [300, 300]                                         ;

y_fit = Fit_CA_2_SEPP_SABRE_nonuniform( MHa1, MHb1,   MH21, MHa2,   MHb2, MH22, ...
                                                                 beta1(1),    beta1(2),     ...
                                                                 beta1(3),    beta1(4),     ...
                                                                 beta1(5),    beta1(6), data_lengths , x_fit_fit   );
                                                             

PAPER = [x_fit, y_fit(1:100),y_fit(101:200),y_fit(201:300),y_fit(301:400),y_fit(401:500),y_fit(501:600)];

%saveas(gcf,'P:\user_permanent\Charbel_Assaf\0_NMR_Data\1_NMR400\20230909_2_13C_Pyr_6\Adjusted\2-13C_[2].png')
toc
%%
%%%%%%%%%%%%%%%%%%Functions%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function [xdata, ydata, data_lengths] = combinealldata(Folder, Files)
                            num_files = length(Files)                      ;

                            xdata     = []                                 ;
                            ydata     = []                                 ;
                         data_lengths = zeros(1, num_files)                ;

    for i = 1: num_files
        loaddata        = load(fullfile(Folder, Files{i}))                 ;
        xdata           = [xdata, loaddata(:, 1)',loaddata(:, 1)',loaddata(:, 1)'] ;                
        ydata           = [ydata, loaddata(:, 2)',loaddata(:, 3)',loaddata(:, 4)'] ;
        data_lengths(i) = 3*length(loaddata(:, 1))                         ;
    end

    xdata = xdata'                                                         ;
    ydata = ydata'                                                         ;
end

function RMSD  = plotNkinetics_loc(N,x,y,xsim,ysim,L)
                               
    figure("Color","white",'DefaultAxesFontSize',20,'Position',[700 0 850 800])
    c = 0                                                                  ;
    for k = 1:N
        subplot(N,1,k)
        semilogx(x(c+1:c+L(k)/3),y((c+1:c+L(k)/3)),"oblack",x(c+1:c+L(k)/3),y((c+1+L(k)/3:c+2*L(k)/3)),"or",x(c+1:c+L(k)/3),y((c+1+2*L(k)/3:c+L(k))),"ob")
        hold on
        semilogx(xsim(c+1:c+L(k)/3),ysim((c+1:c+L(k)/3)),"black",xsim(c+1:c+L(k)/3),ysim((c+1+L(k)/3:c+2*L(k)/3)),"red",xsim(c+1:c+L(k)/3),ysim((c+1+2*L(k)/3:c+L(k))),"blue","LineWidth",2) ;
        hold off
        
        xlabel("𝜏_e (s)",'Fontsize',22)
        ylabel("Integrals (norm.)")
        axis([0.001,max(x)+10,-0.1,1.1])
        RMSD = rms(y((c+1:c+L(k)))-ysim((c+1:c+L(k))))                     ;
        legend({"H_a","H_b","H_2","Fitting","Fitting","Fitting"})
        legend('boxoff')
%        title(sprintf("RMSD = %.4f",RMSD))                                 ;
        c = c + L(k)                                                       ;
    end
end