%%% this script is made to analyse 2 set of data of carbon exchange from [1] to [2] and [2] to [1] using global fit. 
% 
clear all
close all 
tic
p = LoadPath('CA')                                                         ;

% Choosing the fitting Model 

Model_types{1} = '13C2-[1]↔13C2-[2]↔13C2-free'                           ; % kd_IrHH_Ha_DMSO_150mM_[3]_norm.txt
Model_types{2} = '13C2-[1]↔13C2-[2]↔13C2-free_alpha'                     ; % with correction of second set to enhance fitting

Model_type     = Model_types  {2}                                          ; % choose the Fitting Model

%%
%%%%%%%%%%%%%%%%%%%%%% Load all data  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Folder         = "IrHH_data\"                                              ;

Files{1}       = "kd_pyr_DMSO_[1]\kd_pyr_DMSO_50mM_[1].txt"                ; %  || kd_pyr_pressure_[1]\kd_pyr_press_75PSI_[1]_100mM   kd_IrHH_DMSO_[3]\kd_IrHH_Ha_DMSO_150mM_[3]_norm
Files{2}       = "kd_pyr_DMSO_[2]\kd_pyr_DMSO_50mM_[2].txt"                ; % kd_IrHH_DMSO_[3]\kd_IrHH_Hb_DMSO_150mM_[3]_norm.txt

%%%%% Initial parameter guesses %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
initial_params = [0.13,     0.3,    0.02, ...
                  0.02,     0.1,     0.3, ...
                     1,       1,     0.1,    ]                             ;
%% %%%%%%%%%%%%%% Fitting all combined data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
switch Model_type
         
       case '13C2-[1]↔13C2-[2]↔13C2-free'
alpha                        = 1                                           ;
[xdata,ydata, data_lengths]  = combinealldata(Folder,Files,alpha)          ;           
MC11 = 1        ;   MC21 = 0               ;   MCF1 = 0                    ; % 1 0 0
MC22 = 1        ;   MC12 = 0               ;   MCF2 = MCF1                 ; % 1 0 0


%%%%%%%%%%%%%% Define the fitting function %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fitting_function = @(params, x) Fit_CA_2_SEPP_SABRE_kd_pyr_nonuniform( MC11, MC21,   MCF1, MC22,   MC12, MCF2, ...  % add fnorm
                                                                 params(1),    params(2),  params(3),   ...
                                                                 params(4),    params(5),  params(6),   ...
                                                                 params(7),    params(8),  params(9), data_lengths, x   ); % (MC11,MC21,MCF1,MC22,MC12,MCF2,kd1,kd2,kaprime1,kaprime2,kex1, kex2, R1,R2,Rf,L, x)
      case '13C2-[1]↔13C2-[2]↔13C2-free_alpha'
          
alpha                        = 7                                           ;
[xdata,ydata, data_lengths]  = combinealldata(Folder,Files,alpha)          ;     
              
MC11  = 1        ;   MC21 = 0               ;   MCF1 = 0                   ;
MC22  = 1        ;   MC12 = 0               ;   MCF2 = MCF1                ;

%%%%%%%%%%%%%% Define the fitting function %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fitting_function = @(params, x) Fit_CA_2_SEPP_SABRE_kd_pyr_nonuniform_alpha( MC11, MC21,   MCF1, MC22,   MC12, MCF2, ...  % add fnorm
                                                                 params(1),    params(2),  params(3),   ...
                                                                 params(4),    params(5),  params(6),   ...
                                                                 params(7),    params(8),  params(9), data_lengths, x ,alpha ); % (MC11,MC21,MCF1,MC22,MC12,MCF2,kd1,kd2,kaprime1,kaprime2,kex1, kex2, R1,R2,Rf,L, x)         
    
end                                                             
%%%%%%%%%%%%%% Perform the fitting using nlinfit %%%%%%%%%%%%%%%%%%%%%%%%%%
[beta1,R,J,CovB] = nlinfit(xdata, ydata, fitting_function, initial_params) ;% ydata_norm

ysim             = fitting_function(beta1,xdata)                           ;
SE               = sqrt(diag(CovB))                                        ;

%%%%%%%%%%%%%%%%%%% Display the fitted parameters %%%%%%%%%%%%%%%%%%%%%%%%%
kd1                = beta1(1)                                              ;
kd2                = beta1(2)                                              ;
kaprime1           = beta1(3)                                              ;
kaprime2           = beta1(4)                                              ;
kex1               = beta1(5)                                              ;
kex2               = beta1(6)                                              ;
R1                 = beta1(7)                                              ;
R2                 = beta1(8)                                              ;
RF                 = beta1(9)                                              ;

disp('Fitted Parameters:')                                                 ;
fprintf('kd1  = %.3f ± %.3f s^-1 \n\r',[kd1,SE(1)])                        ;
fprintf('kd2  = %.3f ± %.3f s^-1 \n\r',[kd2,SE(2)])                        ;
fprintf('kaprime1 = %.3f ± %.3f s^-1 \n\r',[kaprime1,SE(3)])               ;
fprintf('kaprime2 = %.3f ± %.3f s^-1 \n\r',[kaprime2,SE(4)])               ;
fprintf('kex1 = %.3f ± %.3f s^-1 \n\r',[kex1,SE(5)])                       ;
fprintf('kex2 = %.3f ± %.3f s^-1 \n\r',[kex2,SE(6)])                       ;
fprintf('R1 = %.3f ± %.3f s^-1 \n\r',[R1,SE(7)])                           ;
fprintf('R2 = %.3f ± %.3f s^-1 \n\r',[R2,SE(8)])                           ;
fprintf('RF = %.3f ± %.3f s^-1 \n\r',[RF,SE(9)])                           ;

%% 
 
%%%%%%%%%%%%%%%%%% Plotting %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
plotNkinetics_loc(2,xdata,ydata,xdata,ysim,data_lengths,alpha)                   ;

%%%%%%%%%%%% Increasing the number of the fitting points %%%%%%%%%%%%%%%%%%


x_fit                     = logspace(log10(min(xdata)),log10(max(xdata)),100)' ;
x_fit_fit                 = reshape(x_fit*[1,1,1,1,1,1],6*length(x_fit),1)     ;
data_lengths              = [300, 300]                                         ;

y_fit = Fit_CA_2_SEPP_SABRE_kd_pyr_nonuniform( MC11, MC21,   MCF1, MC22,   MC12, MCF2, ...
                                                   beta1(1),    beta1(2),   beta1(3),  ...
                                                   beta1(4),    beta1(5),   beta1(6),  ...
                                                   beta1(7),    beta1(8),   beta1(9), data_lengths , x_fit_fit   );
                                                         

%PAPER = [x_fit, y_fit(1:100),y_fit(101:200),y_fit(201:300),y_fit(301:400),y_fit(401:500),y_fit(501:600)];

toc
%%
%%%%%%%%%%%%%%%%%%Functions%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function [xdata, ydata, data_lengths] = combinealldata(Folder, Files,alpha)
                            num_files = length(Files)                      ;

                            xdata     = []                                 ;
                            ydata     = []                                 ;
                         data_lengths = zeros(1, num_files)                ;

    for i = 1: num_files
        loaddata        = load(fullfile(Folder, Files{i}))                 ;
        xdata           = [xdata, loaddata(:, 1)',loaddata(:, 1)',loaddata(:, 1)'] ;                
        ydata           = [ydata, loaddata(:, 2)',alpha*loaddata(:, 4)',loaddata(:, 3)'] ;
        data_lengths(i) = 3*length(loaddata(:, 1))                         ;
    end

    xdata = xdata'                                                         ;
    ydata = ydata'                                                         ;
end

function RMSD  = plotNkinetics_loc(N,x,y,xsim,ysim,L,alpha)
                               
    figure("Color","white",'DefaultAxesFontSize',20,'Position',[700 0 850 800])
    c = 0                                                                  ;
    for k = 1:N
        subplot(N,1,k)
        semilogx(x(c+1:c+L(k)/3),y((c+1:c+L(k)/3)),"oblack",x(c+1:c+L(k)/3),y((c+1+L(k)/3:c+2*L(k)/3))/alpha,"or",x(c+1:c+L(k)/3),y((c+1+2*L(k)/3:c+L(k))),"ob")
        hold on
        semilogx(xsim(c+1:c+L(k)/3),ysim((c+1:c+L(k)/3)),"black",xsim(c+1:c+L(k)/3),ysim((c+1+L(k)/3:c+2*L(k)/3))/alpha,"red",xsim(c+1:c+L(k)/3),ysim((c+1+2*L(k)/3:c+L(k))),"blue","LineWidth",2) ;
        hold off
        
        xlabel("𝜏_e (s)",'Fontsize',22)
        ylabel("Integrals (norm.)")
        axis([0.001,max(x)+100,-0.1,1.1])
        RMSD = rms(y((c+1:c+L(k)))-ysim((c+1:c+L(k))))                     ;
        legend({"[1]","f-pyr","[2]"})
        legend('boxoff')
%       title(sprintf("RMSD = %.4f",RMSD))                                 ;
        c = c + L(k)                                                       ;
    end
end