clear all
close all 
tic
p              = LoadPath('CA')                                            ;

%% Loading Experimental data 
%%% load experimental data 
%%% n is the reference of the data in the file 
n             = 'kd_pyr_temp_267K_[2]'                                    ; %                                                                               
File          = "IrHH_data\kd_pyr_temp_[2]\"                               ; %  
data_in       = load(File + n + '.txt','-ASCII')                           ;
data.dmix0    = data_in(:,1)                                               ;
data.dmix     = data.dmix0-data.dmix0(1)                                   ; % Here we take in consideration that first point starts from 0 and all dmix are adjusted
data.c2_b2    = data_in(:,2)                                               ; %  bound pyr 206.6  ppm depends on the experiment
data.c2_b1    = data_in(:,4)                                               ; %  bound pyr 196    ppm depends on the experiment
data.c2_free  = data_in(:,3)                                               ; %  free  pyr 202.5  ppm 


% Choosing the fitting Model 

Model_types{1} = 'carbon_exchange'                                         ;
Model_types{2} = 'carbon_exchange_kaprime'                                 ;
Model_types{3} = 'Biexponential'                                           ;


Model_type     = Model_types  {2}                                          ; % choose the Fitting Model

            
switch Model_type
         
  
      case 'carbon_exchange'                                                  
            
            fprintf("start to fit with IrHH->H2 Matrix model \n")
            Mc2_b2 = 1  ;   Mc2_b1 =  0  ;       Mc2_free = 0                           ;%data.H2(1)      ; % data.c2_b1(1)         data.Hb(1)  ;   data.H2(1) 
            data.r                        = zeros(size(data.dmix))                                                                   ; %     
            Nt                            = length(data.dmix)                                                                        ;
            xdata_fit                     = reshape(data.dmix*[1,1,1],3*Nt,1)                                                        ;
            ydata                         = [data.c2_b2; data.c2_b1; data.c2_free ]                                                  ; % the three sets of ydata values
            i_params                      = [ 0.019, 0.180, 0.173, 0.3, 0.5, 0.14]                                              ; %   kd, kex, RH2, kaprime , Rb
            
            % Initial guess                                                                    (MHa, MHb, MH2,              kd,         kex,    kaprime ,         RH2,         RHa,       RHb, x)
            fitfunc                       = @(i_params, x)SABRE_carbon_exchange_Lmatrix_3R(Mc2_b2, Mc2_b1, Mc2_free, i_params(1), i_params(2), i_params(3), i_params(4), i_params(5),i_params(6), x)  ;
            y0                            = SABRE_carbon_exchange_Lmatrix_3R(Mc2_b2, Mc2_b1, Mc2_free, i_params(1), i_params(2),i_params(3),i_params(4), i_params(5),i_params(6),xdata_fit )           ;
            semilogx(data.dmix, data.c2_b2, 'o', data.dmix, data.c2_b1, 'o',data.dmix, data.c2_free, 'o',data.dmix,reshape(y0,Nt,3))            ;                                                                                                             
            title("initial guess")
            [beta1,R,J,CovB]              = nlinfit(xdata_fit,ydata,fitfunc, i_params)                                               ;
            coefficients_standard_errors  = sqrt(diag(CovB))                                                                         ;
            CSE                           = coefficients_standard_errors                                                             ; 
            fprintf("results: \n")                                                                                                   ;
            fprintf("Model carbon_exchange has kd = %.3f ± %.3f s-1,kex = %.3f ± %.3f s-1, kaprime = %.3f ± %.3f s-1 , RH2 = %.3f ± %.3f s-1, RHa = %.3f ± %.3f s-1, RHb = %.3f ± %.3f s-1 \n",beta1(1),CSE(1),beta1(2),CSE(2),beta1(3),CSE(3),beta1(4),CSE(4),beta1(5),CSE(5),beta1(6),CSE(6))
        
        case 'carbon_exchange_kaprime'                                                  
            
            fprintf("start to fit with IrHH->H2 Matrix model \n")
            Mc2_b2 = 1 ;   Mc2_b1 = 0  ;       Mc2_free = 0                    ;%data.H2(1)      ; % data.Ha(1)  ;          data.Hb(1)  ;   data.H2(1) 
            data.r                        = zeros(size(data.dmix))                                                                   ; %     
            Nt                            = length(data.dmix)                                                                        ;
            xdata_fit                     = reshape(data.dmix*[1,1,1],3*Nt,1)                                                        ;
            ydata                         = [data.c2_b2; data.c2_b1; data.c2_free ]                                                  ; % the three sets of ydata values
            i_params                      = [ 0.019, 0.18, 0.160, 0.004, 0.4,0.4,0.06,0.2,0.7]                                         ; %  kd1,kd2,kaprime1,kaprime2,kex1, kex2, R1,R2,Rf
            
            % Initial guess                                                                   MHa,    MHb,      MH2,         kd1,         kd2, kaprime1,       kaprime2,     kex1, kex2,  R1, R2,  Rf,x
            fitfunc                       = @(i_params, x)SABRE_carbon_exchange_Lmatrix_3R(Mc2_b2, Mc2_b1, Mc2_free, i_params(1), i_params(2), i_params(3), i_params(4), i_params(5),i_params(6),i_params(7),i_params(8),i_params(9),x)  ;
            y0                            = SABRE_carbon_exchange_Lmatrix_3R(Mc2_b2, Mc2_b1, Mc2_free, i_params(1), i_params(2),i_params(3), i_params(4),i_params(5),i_params(6),i_params(7),i_params(8),i_params(9),xdata_fit )           ;
            semilogx(data.dmix, data.c2_b2, 'o', data.dmix, data.c2_b1, 'o',data.dmix, data.c2_free, 'o',data.dmix,reshape(y0,Nt,3)) ;                                                                                                             
            title("initial guess")
            [beta1,R,J,CovB]              = nlinfit(xdata_fit,ydata,fitfunc, i_params)                                               ;
            coefficients_standard_errors  = sqrt(diag(CovB))                                                                         ;
            CSE                           = coefficients_standard_errors                                                             ; 
            fprintf("results: \n")                                                                                                   ;
            fprintf("Model carbon_exchange_kaprime has kd1 = %.3f ± %.3f s-1, kd2 = %.3f ± %.3f s-1, kaprime1 = %.3f ± %.3f s-1, kaprime2 = %.3f ± %.3f s-1, k1->2 = %.3f ± %.3f s-1, k2->1 = %.3f ± %.3f s-1\n",beta1(1),CSE(1),beta1(2),CSE(2),beta1(3),CSE(3),beta1(4),CSE(4),beta1(5),CSE(5),beta1(6),CSE(6))    
            fprintf("Rf = %.3f ± %.3f s-1, R1 = %.3f ± %.3f s-1, R2 = %.3f ± %.3f s-1 \n",beta1(9),CSE(9),beta1(7),CSE(7),beta1(8),CSE(8))    
            
        case 'Biexponential'  
            
            fprintf("start to fit with biexponential model \n") 
            K                          = 10      ;%data.K(n)                                                                        ;                                                                            
            Nt                         = length(data.dmix)                                                                          ;
            xdata_fit                  = reshape(data.dmix*[1,1],2*Nt,1)                                                            ;
            ydata                      = [data.c2_b2; data.c2_b1]                                                                         ; % the two sets of ydata values
            initial_params             = [-1, 0, 0.5, 0.5, 0.3, 0.01]                                                               ; % A1, A2, A3, A4,  k, R1 % Initial constant guess
            fitfunc                    = @(params, x) Fit_CA_SEPPSABRE(params(1), params(2), params(3), params(4), params(5),params(6), x) ;
            [beta1,R,J,CovB]           = nlinfit(xdata_fit, ydata, fitfunc, initial_params)                                         ;
            ysim                       = fitfunc(beta1,xdata_fit)                                                                   ;
            SE                         = sqrt(diag(CovB))                                                                           ;
            k                          = beta1(5)                                                                                   ;
            R1                         = beta1(6)                                                                                   ;
            disp('Model Biexponential has Fitted Parameters:')                                                                      ; 
            fprintf('k  = %.2f ± %.2f Hz & R = %.2f ± %.2f Hz & kd = %.2f ± %.2f Hz \n\r',[k,SE(5),R1,SE(6),k/(1+1/K),SE(5)/(1+1/K)])   ;
                 

end
%%
      switch Model_type
         
   
         case {'carbon_exchange','carbon_exchange_kaprime'}
           
            figure("Color","white",'DefaultAxesFontSize',20,'Position',[1500 500 850 800])                                          ;
            semilogx(data.dmix0, data.c2_b2, 'oblack', data.dmix0, data.c2_b1, 'or',data.dmix0, data.c2_free, 'ob')                 ;
            hold on                                                                                                                 ;
            x_fit                     = logspace(log10(min(data.dmix0)),log10(max(data.dmix0)),100)'                                ;
            x_fit_fit                 = reshape(x_fit*[1,1,1],3*length(x_fit),1)                                                    ;
            y_fit                     = fitfunc(beta1,x_fit_fit)                                                                    ;
            semilogx(x_fit, y_fit(1:100), 'black',x_fit, y_fit(101:200), 'red',x_fit, y_fit(201:end), 'blue')                       ;
            ylim([-0.1 1.1])                                                                                                        ;
            xlim([data.dmix(1) data.dmix(end)])
            legend('^1^3C^2-[2]', '^1^3C^2-[1]', '^1^3C^2-free','Fitting')                                                          ;
            PAPER                     = [ x_fit, y_fit(1:100), y_fit(201:end),y_fit(101:200)]                                       ;
            PAPER                    = [x_fit, y_fit(1:100), y_fit(101:200),y_fit(201:end)]                                        ;
            %csvwrite(File+'_simdata_'+ Model_type +'.csv',PAPER) 

       case 'Biexponential'
           
            figure("Color","white",'DefaultAxesFontSize',20,'Position',[1500 500 850 800])                                          ;
            semilogx(data.dmix0, data.c2_b2, 'oblack', data.dmix0, data.c2_b1, 'or')                                                      ;
            hold on                                                                                                                 ;
            x_fit                     = logspace(log10(min(data.dmix0)),log10(max(data.dmix0)),100)'                                ;
            x_fit_fit                 = reshape(x_fit*[1,1],2*length(x_fit),1)                                                      ;
            y_fit                     = fitfunc(beta1,x_fit_fit)                                                                    ;
            semilogx(x_fit, y_fit(1:100), 'black',x_fit, y_fit(101:end), 'r')                                                       ;
            ylim([-0.1 1.1])                                                                                                        ;
            xlim([data.dmix(1) data.dmix(end)+20])
            legend('bound Pyr','Free Pyr','Fitting', 'Fitting')                                                                     ;
            %PAPER                     = [x_fit, y_fit(1:100), y_fit(101:end)]                                                      ;
      end 
toc