%% start %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all; %clear all and delete all previous data
tic
p=LoadPath();
%% change parameters here
JAX=6; % AX spin coupling
Folder = "out\MFC";
%% Load System %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
System=Load_System_Name(46); %AX is system 41 %A2X is system 42; %A3X is system 43 % A3XX 48
ex=Load_System(System,JAX);
ex.Folder=Folder+System+"_.mat";
%% get initial state %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%InSt = "from_file"
InSt = "artificial";
switch InSt
    case "artificial"
        pA = My_sph2cart(20, 70, 1) % X=0,0, Y=90,0, Z=0,90 polarization vector of spins A        
        pX = My_sph2cart(20,  70, 1) % X=0,0, Y=90,0, Z=0,90 polarization vector of spins X
        pAX_ZZ = 0; 
        pAX_ZZZ = 0*20; 
        r0   = DensityMatrix(ex.S.U +((pA(1)*ex.S.Dir("X",1:ex.S.N-1) + pX(1)*ex.S.Dir("X",ex.S.N))+...
                                      (pA(2)*ex.S.Dir("Y",1:ex.S.N-1) + pX(2)*ex.S.Dir("Y",ex.S.N))+...
                                      (pA(3)*ex.S.Dir("Z",1:ex.S.N-1) + pX(3)*ex.S.Dir("Z",ex.S.N)))/2^3);

        % add this term if you need to add other spin orders
        r0.val=r0.val+pAX_ZZ*ex.S.Dir("Z",ex.S.N)*ex.S.Dir("Z",1:3)/2^2;
        r0.val=r0.val+pAX_ZZZ*ex.S.Dir("Z",ex.S.N)*(ex.S.Dir("Z",1)*ex.S.Dir("Z",2)+ex.S.Dir("Z",2)*ex.S.Dir("Z",3)+ex.S.Dir("Z",3)*ex.S.Dir("Z",1))/2^1;
    case "from_file"
        in=load("out\SABRESHEATH_HH-2C-Pyruvate_B400nT_Kd1.mat");
        r6=in.ex.Yout.rC;
        S6=in.ex.Sc;
        r0=r6.trace2First(S6);
        r0.ShowOperators(ex.S,1e-4);        
        %r0=r0.RotationSuperOperator(pi/2,'Y',ex.S,1:4);       
end
%% magnetic field cycling
%% set MFC
% !!! set your magnetic field profile here !!!
ex.MFC.Nsteps=10e3;
ex.MFC.time=linspace(0,4,ex.MFC.Nsteps)'; % MFC time in [s]
Bx=linspace(0,1300,ex.MFC.Nsteps)'*1e-9+8e-9;
By=linspace(0,0,ex.MFC.Nsteps)'*1e-9;
Bz=linspace(1300,0,ex.MFC.Nsteps)'*1e-9;
%
ex.MFC.B=[Bx,By,Bz]; % MFC field [T]
ex.MFC.dt=ex.MFC.time(2)-ex.MFC.time(1);
figure('Color','white')
subplot(2,1,1);
plot(ex.MFC.time,ex.MFC.B*1e6,'LineWidth',2);
ylabel('Magnetic field (uT)')
xlabel('time (s)')
legend({'B_x';'B_y';'B_z'})


%% calculate MFC
ex.MFC.Px=zeros(ex.MFC.Nsteps,2);
ex.MFC.Py=zeros(ex.MFC.Nsteps,2);
ex.MFC.Pz=zeros(ex.MFC.Nsteps,2);

for ib=1:ex.MFC.Nsteps % here i calculate amplitudes before evolutoin at each step, so that the initial conditions is as set
    B=ex.MFC.B(ib,:);
    dt=ex.MFC.dt;    
    AmpTemp=real(r0.Amplitudes(ex.SOs));
    ex.MFC.Px(ib,:)=[sum(AmpTemp(1:3))/3,AmpTemp(4)];
    ex.MFC.Py(ib,:)=[sum(AmpTemp(5:7))/3,AmpTemp(8)];
    ex.MFC.Pz(ib,:)=[sum(AmpTemp(9:11))/3,AmpTemp(12)];
    H=2*pi*HXYZJij(ex.S,ex.PPM,ex.J,B,"full");
    r0.val=expm(-1i*H*dt)*r0.val*expm(1i*H*dt);
end

%% plot polarizatio nduring MFC
subplot(2,1,2)
plot(ex.MFC.time,[ex.MFC.Px, ex.MFC.Py, ex.MFC.Pz],'LineWidth',2);
ylabel('Polarizatoin [-1:1]');
xlabel('time (s)');
legend({'P_X(A_3)';'P_X(X)';'P_Y(A_3)';'P_Y(X)';'P_Z(A_3)';'P_Z(X)'})
%%
disp('initial state A3')
disp([ex.MFC.Px(1,1),ex.MFC.Py(1,1),ex.MFC.Pz(1,1)])
disp('initial state X')
disp([ex.MFC.Px(1,2),ex.MFC.Py(1,2),ex.MFC.Pz(1,2)])
disp('final state A3')
disp([ex.MFC.Px(end,1),ex.MFC.Py(end,1),ex.MFC.Pz(end,1)])
disp('fiinal state X')
disp([ex.MFC.Px(end,2),ex.MFC.Py(end,2),ex.MFC.Pz(end,2)])
%%%%%%%%%%%%%%%%%%%%%%%%%% end %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
toc










function V = My_sph2cart(azimuth, elevation, r)
% azimuth is the counterclockwise angle in the xy plane measured from the positive x axis.  
% elevation is the elevation angle from the xy plane.
% both are in degrees
 [x,y,z] = sph2cart(azimuth/180*pi, elevation/180*pi,r);
 V=[x,y,z];
end
