%% start %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all; %clear all and delete all previous data
tic
p = LoadPath();
%% Load System %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
System_type{1}="HHN-1"     ;
System_type{2}="HHNN-2"    ;
System_type{3}="HHC-1"     ;
System_type{4}="HHHC-1"    ;
System_type{5}="HH-HHHC-1" ;

System=System_type{2}   ;
ex=Load_SABRE_System(System)   ;
ex.System = System      ;
%% kinetic parameters %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ex.fpH = 0.52                                         ; % pH2 fraction (1 is 100)
ex.Kd  = 10                                           ; % [s^-1] dissociation rate
Concentrationofcomplex   = 4                          ; % Concentration of complex [mM] %  4.68  
Concentrationofsubstrate = 40                         ; % Concentration of substrate [mM] % 41
n = Concentrationofcomplex/Concentrationofsubstrate   ;
ex.Wa  = ex.Kd*n                                      ; % [s^-1] association rate

%% Sequence to measure %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ESOTHERIC_types{1} = 'SABREESOTHERIC'                 ;
ESOTHERIC_types{2} = 'SABREESOTHERIC_2D_TA_TB'        ;
ESOTHERIC_types{3} = 'SABREESOTHERIC_2D_TA_vdList'    ;
ESOTHERIC_types{4} = 'SABREESOTHERIC_2D_TB_vdList'    ;
ESOTHERIC_types{5} = 'SABREESOTHERIC_TAvd_Multi_Kd'   ;
ESOTHERIC_types{6} = 'SABREESOTHERIC_TBvd_Multi_Kd'   ;
ESOTHERIC_types{7} = 'SABREESOTHERIC_tev'             ;
ESOTHERIC_types{8} = 'SABREESOTHERICtev_Multi_Kd'     ;

ESOTHERIC_type     = ESOTHERIC_types{5}                   ;  
ex.ESOTHERIC_type  = ESOTHERIC_type                       ;
ex.Folder          = "out\"+System+"\ESOTHERIC\"+ESOTHERIC_type+"\"+ESOTHERIC_type+"_"      ;  

%%  parameters %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ex.B0        = 9.4                    ; % observation magnetic field [T]
ex.prebubble = 10                     ; % perbubble [s]

%% calculate pulsed SABRE%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    switch ESOTHERIC_type
        case 'SABREESOTHERIC'
              ex.t1v  = 6e-3                                         ; %1e-3*linspace(0,50,51)'    
              ex.t2v  = 20e-3                                        ; %%                          
              Yout = sabre_Esotheric_SOT(ex)                         ; 
        case 'SABREESOTHERIC_2D_TA_TB'
              ex.t1v  = 1e-3*linspace(0,50,51)                       ; 
              ex.t2v  = 1e-3*linspace(0,50,51)                       ;
              Yout = sabre_Esotheric_SOT(ex)                         ; 
        case 'SABREESOTHERIC_2D_TA_vdList'
              ex.t1v  = 1e-3*linspace(0,40,41)                       ; 
              ex.t2v  = 5e-3                                         ; 
              Yout = sabre_Esotheric_TBvd_SOT(ex)                    ; 
        case 'SABREESOTHERIC_2D_TB_vdList'
              ex.t1v  = 6e-3                                         ; 
              ex.t2v  = 1e-3*linspace(0,50,51)                       ;
              Yout = sabre_Esotheric_SOT(ex)                         ; 
        case 'SABREESOTHERIC_TAvd_Multi_Kd'   
              ex.t1v   = 1e-3*linspace(0,50,51)'                     ;
              ex.t2v   = 5e-3                                        ;
              Kd_range = 40:0.1:80                                   ; 
              for  kk = 1:length(Kd_range)
                   kk/length(Kd_range)*100
                   ex.Kd  = Kd_range(kk)                             ; 
                   ex.Wa  = ex.Kd*n                                  ;
                   Yout   = sabre_Esotheric_TAvd_SOT(ex)             ;
                   out    = [ex.t1v,((Yout.c{14}+Yout.c{15})/2)]     ; 
                   save(ex.Folder+ex.Kd+'.csv','out','-ASCII')       ;
              end
        case 'SABREESOTHERIC_TBvd_Multi_Kd'   
              ex.t1v   = 5e-3                                        ;
              ex.t2v   = 1e-3*linspace(0,50,51)                      ;
              Kd_range = 8:0.1:60                                    ; 
              for  kk = 1:length(Kd_range)
                   kk/length(Kd_range)*100
                   ex.Kd  = Kd_range(kk)                             ; 
                   ex.Wa  = ex.Kd*n                                  ;
                   Yout   = sabre_Esotheric_TBvd_SOT(ex)             ;
                   out    = [ex.t2v, (Yout.c{14}+Yout.c{15}/2)]      ; 
                   save(ex.Folder+ex.Kd+'.csv','out','-ASCII')       ;
              end
        case 'SABREESOTHERIC_tev'
                ex.t1v  = 9e-3                                       ; 
                ex.t2v  = 9e-3                                       ;
                ex.taugrad = 0.002                                   ; % gradients pulses applied for 2 ms before te delays
                ex.tev  = [0.01:0.01:0.1, 0.2:0.1:1, 2:1:10, 20]'    ;
                Yout    = sabre_Esotheric_Te_SOT(ex)                 ; 
%                 out     = [ex.tev,Yout.c{3}]                         ; 
%                 save(ex.Folder+ex.Kd+'.csv','out','-ASCII')          ;
        case 'SABREESOTHERICtev_Multi_Kd'
                 ex.t1v     = 20e-3                                  ; 
                 ex.t2v     = 10e-3                                  ;
                 ex.taugrad = 0.002                                  ; % gradients pulses applied for 2 ms before te delays
                 ex.tev     = [0.01:0.01:0.1, 0.2:0.1:1, 2:1:10, 20]';
                 Kd_range   = 20:0.1:22                              ;
                  for  kk =1:length(Kd_range)
                       kk/length(Kd_range)*100
                       ex.Kd  = Kd_range(kk)                         ; 
                       ex.Wa  = ex.Kd*n                              ;
                       Yout   = sabre_Esotheric_Te_SOT(ex)           ;
%                        out    = [ex.tev,((Yout.s{6}+Yout.s{9})/2)'] ;
%                        save(ex.Folder+ex.Kd+'.csv','out','-ASCII')  ;
                  end
                         
    end

%% plot %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

  switch ESOTHERIC_type
      case 'SABREESOTHERIC_Multi_Kd'
            figure;
            set(gcf,'color','w')                                                         ;
            plot(ex.t1v*1e3,((Yout.c{14}+Yout.c{15})/2),'b','LineWidth',2)           
            legend(ex.SOcStr{14}+"+"+ex.SOcStr{15})
       case 'SABREESOTHERIC_2D_TA_TB'
             ex.X = ex.t1v                                                               ;
             ex.Y = ex.t2v                                                               ;
             ex.Z = ((Yout.c{14}+Yout.c{15})/2)                                          ;
             plot_kinetics_2D(ex)
%             out = abs(Yout.c{15})                                                     ;
%             save('out\'+System+'\'+INEPT_type+'\'+INEPT_type+'3.dat','out','-ASCII')  ;
      case {'SABREESOTHERIC_tev','SABREESOTHERICtev_Multi_Kd'}
            figure
            set(gcf,'color','w')                                                         ;
            semilogx(ex.tev,((Yout.s{6}+Yout.s{9})/2),'LineWidth',2)  
            legend(ex.SOsStr{6}+"+"+ex.SOsStr{9})
      case {'SABREESOTHERIC','SABREESOTHERIC_2D_TA_vdList'}
              figure;
              set(gcf,'color','w')                                                       ;
              plot(ex.t1v*1e3,((Yout.c{14}+Yout.c{15})/2),'b','LineWidth',2)           
              legend(ex.SOcStr{14}+"+"+ex.SOcStr{15})
              xlabel('TA (ms)')                                                          ;
              ylabel('Integrals')                                                        ;
              title(sprintf('Integrals (tauB = %.1fms)',ex.t2v*1e3))                     ;
%               out    = [ex.t1v,(Yout.c{14}+Yout.c{15})/2]                              ;
%               save(ex.Folder+'t2v=20ms.csv','out','-ASCII')                            ;
     case 'SABREESOTHERIC_2D_TB_vdList'
              figure;
              set(gcf,'color','w')                                                       ;
              plot(ex.t2v*1e3,((Yout.c{14}+Yout.c{15})/2),'b','LineWidth',2)           
              legend(ex.SOcStr{14}+"+"+ex.SOcStr{15})
              xlabel('TB (ms)')                                                          ;
              ylabel('Integrals')                                                        ;
              title(sprintf('Integrals (tauA = %.1fms)',ex.t1v*1e3))                     ;
%               out    = [ex.t2v,(Yout.c{14}+Yout.c{15})/2]                              ;
%               save(ex.Folder+'t1v=6ms.csv','out','-ASCII')                             ;
      
  end 

%%%%%%%%%%%%%%%%%%%%%%%%%% end %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
toc