% This script helps you to get the FID and the spectrum to know the final state of the spin operators.
% PS: It doesn't change the final state to get the spectrum pulse 0 degree 
%% start %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all                                                                  ; %clear all and delete all previous data
tic
p                 = LoadPath()                                             ;
%% Load System %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
System_type{1}    = "HHN-1"                                                ;
System_type{2}    = "HHNN-2"                                               ;
System_type{3}    = "HH-C"                                                 ;
System_type{4}    = "HHHC-1"                                               ;
System_type{5}    = "HH-HHHC-1"                                            ;
                                    
System            = System_type{3}                                         ;
ex                = Load_SABRE_System(System)                              ;
%ex.Folder="out\SLIC_SHEATH_SABRE_"+System+"_data";
%% kinetic parameters %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ex.fpH            = 0.52                                                   ; % pH2 fraction (1 is 100)
ex.Kd             = 15                                                     ; % [s^-1] dissociation rate
Concentrationofcomplex   = 4.68                                            ; % Concentration of complex [mM]     
Concentrationofsubstrate = 41                                              ; % Concentration of substrate [mM]
n                 = Concentrationofcomplex/Concentrationofsubstrate        ;
ex.Wa             = ex.Kd*n                                                ; % [s^-1] association rate

%%  parameters %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ex.B0             = 9.4                                                    ; % observation magnetic field [T]
ex.t1v            = 5e-3                                                   ;
ex.t2v            = 9e-3                                                   ;
ex.tev            = 2                                                      ;
ex.prebubble      = 10                                                     ;

%% calculate pulsed SABRE%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
initial_states{1} = 'phINEPT'                                              ;
initial_states{2} = 'phINEPTplus'                                          ;
initial_states{3} = 'SABREINEPT'                                           ;
initial_states{4} = 'C1Z3Y+C2Z3Y'                                          ;
initial_states{5} = 'C1Z3Y'                                                ;
initial_states{6} = 'C1Z+C2Z'                                              ;
initial_states{7} = 'C3X+C4X'                                              ;
initial_states{8} = '100%_Magnetization'                                   ;
initial_states{9} = 'all_X'                                                ; 
initial_states{10}= 'Esotheric_SOT'                                        ;
initial_states{11}= 'Esotheric_Te_SOT'                                     ;                      
initial_states{12}= 'SEPPINEPT'                                            ;
initial_state     = initial_states{12}                                     ; % choose the initial state of the system


switch initial_state
    case 'phINEPT'
        Yout     = sabre_inept_SOT(ex)                                     ;  
        rS       = Yout.rS                                                 ;
        rC       = Yout.rC                                                 ;
    case 'phINEPTplus'
        Yout     = sabre_ineptplus_SOT(ex)                                 ;  
        rS       = Yout.rS                                                 ;
        rC       = Yout.rC                                                 ; 
    case 'SABREINEPT'
        ex.taugrad = 0.002                                                 ;
        Yout     = sabre_inept2tev_SOT(ex);  % sabre_inept2_SOT
        rS       = Yout.rS                                                 ;
        rC       = Yout.rC                                                 ;
    case 'C1Z3Y+C2Z3Y'  
        rC       = DensityMatrix(ex.Sc.U + ex.Sc.norm2('z',1,'y',3) + ex.Sc.norm2('z',2,'y',3));%ex.Sc.norm2)+ ex.Sc.norm2('z',2,'y',3)
        rS       = DensityMatrix(ex.Ss.U)                                            ;
    case 'C1Z3Y'  
        rC       = DensityMatrix(ex.Sc.U + ex.Sc.norm2('z',1,'y',3))                 ; % ex.Sc.norm2('z',2,'y',3)
        rS       = DensityMatrix(ex.Ss.U)                                            ;
    case 'C1Z+C2Z'  
        rC       = DensityMatrix(ex.Sc.U + + ex.Sc.norm('z',1) + ex.Sc.norm('z',2))  ; % ex.Sc.norm2('z',2,'y',3)
        rS       = DensityMatrix(ex.Ss.U)                                            ;
    case 'C3XC4X'  
        rC       = DensityMatrix(ex.Sc.U + ex.Sc.norm('x',3) + ex.Sc.norm('x',4))    ; % ex.Sc.norm2('z',2,'y',3)
        rS       = DensityMatrix(ex.Ss.U)                                  ;
    case '100%_Magnetization'  
        rC       = DensityMatrix('100%_Magnetization',ex.Sc)               ;
        rS       = DensityMatrix('100%_Magnetization',ex.Ss)               ;
    case 'all_X'  
        rC       = DensityMatrix(ex.Sc.U + ex.Sc.norm('x',3))              ;
        rS       = DensityMatrix(ex.Ss.U + ex.Ss.norm('x',1))              ;
    case 'Esotheric_SOT'
        Yout     = sabre_Esotheric_SOT_N(ex)                               ;   
        rS       = Yout.rS                                                 ;
        rC       = Yout.rC                                                 ;
    case 'Esotheric_Te_SOT'  
        ex.taugrad = 0.002                                                 ;
        Yout     = sabre_Esotheric_Te_SOT(ex)                              ;  
        rS       = Yout.rS                                                 ;
        rC       = Yout.rC                                                 ;
    case 'SEPPINEPT'
        ex.tau1  =  1/(4*10.5)                                             ;
        Yout     = SABRE_SEPPINEPT_SOT(ex)                                 ;  
        rS       = Yout.rS                                                 ;
        rC       = Yout.rC                                                 ;  
    case 'SEPP'
        Yout     = SABRE_SEPP_SOT(ex)                                      ;  
        rS       = Yout.rS                                                 ;
        rC       = Yout.rC                                                 ;
end


%% spectrum parameters
spec.pulse       = 0                                                       ; % excitation pulse [rad]
%spec.ph1         = 'Y'                                                    ;
%spec.phrec       = 'X'                                                    ;
spec.B0          = ex.B0                                                   ; % observation magnetic field [T]
spec.v0_1H       = spec.B0*ex.Sc.gamma{1}/(2*pi)                           ; % observation frequency, Hz
spec.v0_15N      = spec.B0*ex.Sc.gamma{3}/(2*pi)                           ; % observation frequency, Hz
spec.SW          = 9000                                                    ; % [Hz]
spec.TD          = 1024*8                                                  ; % spectral width and number of points in FID

%% calculate spectrum
%[spec] = sabre_FID(ex,rS,rC,spec);

v0               = spec.v0_15N                                             ;
ppm0             = 0e-6                                                    ; % main frequency and detection frequency in ppm
RegNuc           = [3]                                                     ;
FWHM             = 1                                                       ; % full width half maximum
Hc               = 2*pi*HZJij(ex.Sc,ex.ppmC,ex.JC,spec.B0,"full")                      ; 
[PPM, FRQ, SPEC] = rC.Spectrum(Hc,ex.Sc,spec.SW,spec.TD,-v0,ppm0,RegNuc,FWHM,"-X")     ;
%PlotSpec(FRQ,SPEC,[-4000,-4100])                                                      ;
rC.ShowOperators(ex.Sc,0.001)
 
% % substrate
RegNuc           = [1]                                                     ;
ppm0             = 0e-6                                                    ; % main frequency and detection frequency in ppm
FWHM             = 1                                                       ; % full width half maximum
Hs               = 2*pi*HZJij(ex.Ss,ex.ppmS,ex.JS,spec.B0,"full")                     ;
[PPM, FRQ, SPEC] = rS.Spectrum(Hs,ex.Ss,spec.SW,spec.TD,-v0,ppm0,RegNuc,FWHM,"-X")    ;
%PlotSpec(FRQ,SPEC,[4200,4000])                                                       ;
rS.ShowOperators(ex.Ss,0.001)
 
% SaveData('Spec.dat',[PPM FRQ],[real(SPEC) imag(SPEC)]);

%% plot spectrum
% types_spec{1}="relative FRQ";
% types_spec{2}="absolute FRQ";
% % "all" "c", "s", "1H", "15N"... "1H_c", "1H_s", "15N_c", "15N_s"
% %plot_spectrum(System,ex,spec,types_spec{2},"all");
% plot_spectrum(System,ex,spec,types_spec{2},"c","spectrum")  ;
% %plot_spectrum(System,ex,spec,types_spec{2},"s")  ;
% %plot_spectrum(System,ex,spec,types_spec{2},"15N");
% %plot_4spectra(System,ex,spec,types_spec{2},"all");


%%%%%%%%%%%%%%%%%%%%%%%%%% end %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
toc
