%% start %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all; %clear all and delete all previous data
tic
p=LoadPath();
Folder = "out\ZULF_COSY_";
%% change parameters here %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
spec.B0 = [0,0,51333]*1e-9;           % [T] observation field
spec.Bm = [0,0,1]*1e-9;           % [T] mixing field
spec.R2=1/10;                   % phenomenological 1/T2* = [s-1]
spec.FWHM = 1/(pi*spec.R2);     % FWHM in Hz
spec.SW1=12;                % spetral width in indirect dimension [Hz]
spec.TD1=128;              % number of points in indirect dimension
spec.SW2=5000  ;             % spectral width in direct dimension [Hz]
spec.TD2=128*4 ;           % spectral number of points in FID  
JAX=2;                     % AX spin coupling
pA = -10;                   % polarization of spins A
pX = 10;                    % polarization of the spin X
System_ID = 55;             % AX is system 44 %A2X is system 45; %A3X is system 46
%% Load System %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
System=Load_System_Name(System_ID); 
ex=Load_System(System,JAX);
ex.Folder=Folder+System+"COSY_ZULF_.mat";
%% RF %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ex.RF.Pulse=[80/180*pi,80/180*pi];
ex.RF.Phase=["X";"X"];
va = spec.B0*ex.S.gamma{1}/(2*pi) % Hz
vX = spec.B0*ex.S.gamma{end}/(2*pi) % Hz
%% Initial state %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
r0   = DensityMatrix(ex.S.U + (pA*ex.S.Dir("Z",1:ex.S.N-1) + pX*ex.S.Dir("Z",ex.S.N))); 
%r0 = get_initial_state(12,ex);
%% spectrum parameters %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% spec.Excitation.Spins = []; % excited spins            not used
% spec.Excitation.Phase = 'X'; % excited spins           not used
% spec.Excitation.Pulse = pi/2; % excitation pulse [rad] not used
%% calculate 1 ZULF COSY spectrum %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[spec] = COSY_ZULF_Spectrum(ex,r0,spec); 
%% plot COSY X orientation %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure("color","white")
% plot FID
title("COSY observatoin X")
subplot(2,1,1)
[Y, X]=meshgrid(spec.AQTime1,spec.AQTime2);
Z = (real(spec.FID.X));
surf(X,Y,Z,'LineStyle',"none");
view(2)
ylabel("Time1 (indirect) (s)");
xlabel("Time2 (direct) (s)");
title("time domain")
axis([0, spec.AQTime2(end), 0, spec.AQTime1(end)])

% plot spectrum
subplot(2,1,2)
[Y, X]=meshgrid(spec.FRQ1,spec.FRQ2);
Z=abs(spec.spec.X);
[n2,m2]=max(max(Z));
[n1,m1]=max(Z(:,m2));
Z(m1,m2)
spec.FRQ2(m1)
spec.FRQ1(m2)
surf(X,Y,Z,'LineStyle',"none");
view(2)
axis([0, spec.FRQ2(end), -spec.FRQ1(end), spec.FRQ1(end)])
ylabel("Frequency1 (indirect) (Hz)");
xlabel("Frequency2 (direct) (Hz)");
title("spectrum")
colormap(hot(100));

%% plot COSY Y orientation %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure("color","white")
% plot FID
title("COSY observatoin Y")
subplot(2,1,1)
[Y, X]=meshgrid(spec.AQTime1,spec.AQTime2);
Z = (real(spec.FID.Y));
surf(X,Y,Z,'LineStyle',"none");
view(2)
ylabel("Time1 (indirect) (s)");
xlabel("Time2 (direct) (s)");
title("time domain")
axis([0, spec.AQTime2(end), 0, spec.AQTime1(end)])

% plot spectrum
subplot(2,1,2)
[Y, X]=meshgrid(spec.FRQ1,spec.FRQ2);
Z=abs(spec.spec.Y);
[n2,m2]=max(max(Z));
[n1,m1]=max(Z(:,m2));
Z(m1,m2)
spec.FRQ2(m1)
spec.FRQ1(m2)
surf(X,Y,Z,'LineStyle',"none");
view(2)
axis([0, spec.FRQ2(end), 0, spec.FRQ1(end)])
ylabel("Frequency1 (indirect) (Hz)");
xlabel("Frequency2 (direct) (Hz)");
title("spectrum")
colormap(hot(100));

%% save
imagewd = getframe(gcf); 
imwrite(imagewd.cdata, Folder+System+".tiff",'Compression','none','Resolution',300);   

save(Folder+"_spec.mat","spec")
%spectrum = [real(spec.spec), imag(spec.spec)]; % use this data e.g. to compare with your spectrum 


%%%%%%%%%%%%%%%%%%%%%%%%%% end %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
toc
