%% start %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear; %clear all and delete all previous data
tic
p=LoadPath();
Folder = "out\ZULF_COSY_";
%% Load System %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
spec.B0 = [0,0,6.767]*1e-6;           % [T] 3D observation field [x y z]
System_ID = 46;             % "3FPy" is system 54
System=Load_System_Name(System_ID); 
JAX=1.2;                     % AX spin coupling
ex=Load_System(System,JAX);
ex.Folder=Folder+System+"_p2z.mat";
%% RF %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ex.RF.Pulse=[60/180*pi,60/180*pi];
ex.RF.Phase=["X";"X"];
va = abs(spec.B0(3)*ex.S.gamma{1}/(2*pi)); % Hz
vX = abs(spec.B0(3)*ex.S.gamma{end}/(2*pi)); % Hz
%% change parameters here %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
xaxiswidth=4;             %+-10Hz from central peak
yaxiswidth=5;
spec.Bm =[0,0,0.1]*1e-9;           % [T] mixing field 3D [x y z]
spec.R2=1/10;                   % phenomenological 1/T2* = [s-1]
spec.proc.k = 4; % parameter for appodization / weighting constant

spec.FWHM = 1/(pi*spec.R2);     % FWHM in Hz
spec.SW1=2*yaxiswidth;                % spetral width in indirect dimension [Hz]
spec.TD1=151;                          % number of points in indirect dimension
spec.SW2=2*(max([va,vX])+xaxiswidth)  ;             % spectral width in direct dimension [Hz]
spec.TD2=4674;           % spectral number of points in FID  
pA = 0;                   % polarization of spins A
pX = 0;                    % polarization of the spin X
p4z = 0;
p3z = 0;
p2z = 1;
%% Plot Settings %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
colorbarratio_A_cosy=1; %clim[0 max(spectrum)/colorbarratio] (range of the colorbar)
colorbarratio_X_cosy=1;
FontSize=8;
cbwidth=0.025;
totalsizex=310;
totalsizey=310;
YLabeltime="Frequency2 (direct) (Hz)";
XLabeltime='evolution time [s]';
XLabelcosy="Frequency2 (direct) (Hz)";
YLabelcosy="Frequency1 (indirect) (Hz)";
sgap=0.01;
bgap=0.15;
xlongside=0.63;
ylongside=0.63;
shortside=0.1;
%% Initial state %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
r0   = DensityMatrix(ex.S.U + (pA*ex.S.Dir("Z",1:ex.S.N-1) + pX*ex.S.Dir("Z",ex.S.N))); 
if System_ID==46
    r0.val = r0.val + p4z*ex.S.z{1}*ex.S.z{2}*ex.S.z{3}*ex.S.z{4}; 
    r0.val = r0.val + p3z*(ex.S.z{1}*ex.S.z{2}+ex.S.z{1}*ex.S.z{3}+ex.S.z{2}*ex.S.z{3})*ex.S.z{4}; 
    r0.val = r0.val + p2z*(ex.S.z{1}+ex.S.z{2}+ex.S.z{3})*ex.S.z{4}; 
end
%r0 = get_initial_state(12,ex);
%% calculate 1 ZULF COSY spectrum %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[spec] = COSY_ZULF_FID(ex,r0,spec); 
%%
[spec] = COSY_ZULF_processing(spec);
save(ex.Folder,"spec","-mat")

%% choose relevant data
f=spec.FRQ2;
%ind_f=find(0 <= f & f <=f(end));
ind_A = find((va(end)-xaxiswidth) < f & f <(va(end)+xaxiswidth));
ind_X = find((vX(end)-xaxiswidth) < f & f <(vX(end)+xaxiswidth));
f_A = f(ind_A);
f_X = f(ind_X);
Fl_A=min(f_A);
Fl_X=min(f_X);
Fh_A=max(f_A);
Fh_X=max(f_X);
cosy_A=abs(spec.spec.Y(ind_A,:)).';
cosy_X=abs(spec.spec.Y(ind_X,:)).';
%% calculate projections
%calculate the high field projection for A (mostly hydrogen) 
hfspec_A=zeros(length(cosy_A(1,:)),1); %Length of one row (how many columns do we have) 
for a =1:length(cosy_A(1,:))        %loop over all columns
   hfspec_A(a)=mean(cosy_A(:,a));   %average over the column a
end
%calculate the evolution field projection for A (mostly hydrogen)
efspec_A=zeros(length(cosy_A(:,1)),1); %length of one column (how many rows do we have) 
for a =1:length(cosy_A(:,1))            %loop over all rows
        efspec_A(a)=mean(cosy_A(a,:));  %average over row a
end
%calculate the high field projection for X (here 19F)
hfspec_X=zeros(length(cosy_X(1,:)),1); %Length of one row (how many columns do we have) 
for a =1:length(cosy_X(1,:))          %loop over all columns
   hfspec_X(a)=mean(cosy_X(:,a));     %average over the column a
end
%calculate the evolution field projection for X (here 19F)
efspec_X=zeros(length(cosy_X(:,1)),1);  %length of one column (how many rows do we have) 
for a =1:length(cosy_A(:,1))            %loop over all rows
        efspec_X(a)=mean(cosy_X(a,:));  %average over row a
end
%% perform COSY plots%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
f2 =spec.FRQ1; %frequency axis for the low field
cup_X = max(max(cosy_X))/colorbarratio_X_cosy; %range of the colorbar
cup_A = max(max(cosy_A))/colorbarratio_A_cosy;
fig1=figure;
fig1.Position=[400 200 totalsizex totalsizey];
pos1 = [bgap bgap+ylongside+sgap xlongside shortside];
pos2=[bgap bgap xlongside ylongside];
pos3= [bgap+xlongside+sgap bgap shortside ylongside];
pos4=[bgap+xlongside+sgap+shortside+sgap bgap cbwidth ylongside];
subplot('Position',pos1);
plot(f_X,(hfspec_X))
xlim([Fl_X Fh_X])
set(gca,'visible','off')
subplot('Position',pos2);
imagesc(f_X,f2,cosy_X)
set(gca,'YDir','normal')
clim([0 cup_X])
set(colorbar,'Position',pos4,'FontSize',FontSize,'Box','off')
view(2)
axis([min(f_X), max(f_X),min(f2), max(f2)])
ylabel("Frequency1 (indirect) (Hz)");
xlabel("Frequency2 (direct) (Hz)");
ax = gca;
ax.FontSize = FontSize; 
subplot('Position',pos3);
plot(f2,(efspec_X))
xlim([-yaxiswidth yaxiswidth])
set(gca,'visible','off','XDir','reverse')
camroll(-90)
fontname("Calibri")
saveas(fig1,'simu_Pyridine_C','svg');
fig2=figure;
fig2.Position=[400 200 totalsizex totalsizey];
subplot('Position',pos1);
plot(f_A,(hfspec_A))
xlim([Fl_A Fh_A])
set(gca,'visible','off')
subplot('Position',pos2);
imagesc(f_A,f2,cosy_A)
set(gca,'YDir','normal')
clim([0 cup_A])
set(colorbar,'Position',pos4,'FontSize',FontSize,'Box','off')
view(2)
axis([min(f_A), max(f_A),min(f2), max(f2)])
ylabel("Frequency1 (indirect) (Hz)");
xlabel("Frequency2 (direct) (Hz)");
ax = gca;
ax.FontSize = FontSize; 
subplot('Position',pos3);
plot(f2,(efspec_A))
xlim([-yaxiswidth yaxiswidth])
set(gca,'visible','off','XDir','reverse')
camroll(-90)
fontname("Calibri")
saveas(fig2,'simu_Pyridine_H','svg');
toc
