%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all; %clear all and delete all previous data
LoadPath('AP');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%% calculate PHIP OPE and CPMG performance %%%%%%%%%%%%
tic
System_ID=40; %"Eth-Acetate-d3-spin2" - 40; "Eth-Acetate-spin5" - 57
System=Load_System_Name(System_ID);
ex = Load_System(System);
%Frequency = 2.430581668777235e+07;
%ex.B0=Frequency/(ex.S.gamma{1}/2/pi);
ex.B0=0.4396; % Tesla
%ex.B0=0.55;%0.55;% Tesla
p90=22e-6; % 90o excitation pulse length in [s]
p180=p90*2; % 180o excitation pulse length in [s]
p45=p90/2; % 45o excitation pulse length in [s]
err=0; % value of pulse length error (deviation from nominal), 0 - is no error
v1=1/(4*p90); % nominal B1 amplitude in Hz (v1*(1+err) is the set B1 amplitude)
ppmrf=0e-6; % RF frequency 


%% sequences
SOTs{1}="OPE-45-CPMG-Rn";    % vary number of echoes for the fixed tau
SOTs{2}="OPE-45-CPMG-CPRn";  % vary number of echoes for the fixed tau
SOTs{3}="OPE-45-Rn";         % vary echo time for the fixed number of echoes
SOTs{4}="OPE-45-CPRn";       % vary echo time for the fixed number of echoes
SOT.name=SOTs{4};

%% initial state
H0=2*pi*HZJij(ex.S,ex.PPM,ex.J,ex.B0,"full");
[Q, E]=eig(full(H0));
req=DensityMatrix('100%_SingletSpinOrder',ex.S,ex.n1,ex.n2);%;%initial state
req=req.RemoveCoherences(Q);

%% initialize hamiltonians
H1_0=2*pi*HZJij_RF1(ex.S,ex.PPM,ex.J,ex.B0,0,ppmrf,"X",ex.eH);
H1_X=2*pi*HZJij_RF1(ex.S,ex.PPM,ex.J,ex.B0,v1*(1+err),ppmrf,"X",ex.eH);
H1_Y=2*pi*HZJij_RF1(ex.S,ex.PPM,ex.J,ex.B0,v1*(1+err),ppmrf,"Y",ex.eH);

%% perform calculations
switch SOT.name
    case {SOTs{1:2}} % CPMG
        tau=5*1e-3; % time before the first refocusing (2tau is time between two refocusing blocks)
        ttotal = 1; % total CPMG sequence time
        [TE,nechos,out]=OPE_CPMG(SOT,req,tau,ttotal,H0,H1_X,H1_Y,ex.SOs,p45,p90,p180);
    case {SOTs{3:4}} % OPE
        tau=linspace(1,20,100)*1e-3; % ms % time between 45 and first refocusing
        nechos = 3; % number of refocusing pulses
        [TE,out]=OPE(SOT,req,tau,nechos,H0,H1_X,H1_Y,ex.SOs,p45,p90,p180); % TE = 2 * tau * nechos
        %TE = tau;
end

%% save calculation parameters
sim.name=SOT.name;
sim.System=System;
sim.n=nechos;
sim.B0=ex.B0;
sim.p90=p90;
sim.p180=p180;
sim.p45=p45;
sim.v1_err=err;
sim.ppmrf=ppmrf;
sim.v1=v1;
sim.TE=TE*1e3;

sim.Xavg=0; % initialize average value
sim.Yavg=0; % initialize average value
for k=1:ex.S.N
    sim.X{k}=out(:,k);    
    sim.Y{k}=out(:,k+ex.S.N);    
    sim.Xavg=sim.Xavg+sim.X{k};
    sim.Yavg=sim.Yavg+sim.Y{k};
end
sim.Xavg=sim.Xavg/ex.S.N;
sim.Yavg=sim.Yavg/ex.S.N;

save('out\sim_'+sim.name+num2str(sim.n)+'_'+sim.System+'.mat','sim');

plot_kinetics(sim)

toc
%%%%% finish   Spectroscopy(N=3), Classical Transition approach %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function plot_kinetics(sim)
    figure('Name','Spectrum','Color','white','NumberTitle','off');
    subplot(2,1,1);
    %plot(sim.TE,sim.X{1},'Color','blue','LineWidth',1,'DisplayName','Z OPE-45 Kinetics');
    hold on
    %plot(sim.TE,sim.X{2},'Color','red','LineWidth',1,'DisplayName','Z OPE-45 Kinetics');
    plot(sim.TE,sim.Xavg,'Color','green','LineWidth',1,'DisplayName','Z OPE-45 Kinetics');
    ylabel('Z magnetization a.u.');
    %legend(["H1X","H2X","(H1X+H2X)/2"])
    legend(["avgH_X"])
    title(sim.name+" for "+sim.System);

    subplot(2,1,2);
    %plot(sim.TE,sim.Y{1},'Color','black','LineWidth',1,'DisplayName','Z OPE-45 Kinetics');
    hold on
    %plot(sim.TE,sim.Y{2},'Color','cyan','LineWidth',2,'DisplayName','Z OPE-45 Kinetics');
    plot(sim.TE,sim.Yavg,'Color','magenta','LineWidth',2,'DisplayName','Z OPE-45 Kinetics');
    %legend(["H1Y","H2Y","(H1Y+H2Y)/2"])
    legend(["avgH_Y"])
    xlabel('TE [ms]');
    ylabel('Z magnetization a.u.');
end

function [TE, n, out]=OPE_CPMG(SOT,rin,tau,ttotal,H0,H1_X,H1_Y,SOs,p45,p90,p180)
    n = floor(ttotal / (2*tau));
    TE = (1:n)*2*tau;
    t_evol=tau;
    out=zeros(n,length(SOs));
    [t,A,r0]=rin.EvolutionConstH(H1_Y,p45,[]); %rotation             
    r1=r0;
    switch SOT.name
        case "OPE-45-CPMG-Rn" 
            print_progress(0)
            for in=1:n
                print_progress(in/n)
                [t,A,r1]=r1.EvolutionConstH(H0,t_evol,[]);  

                [t,A,r1]=r1.EvolutionConstH(H1_Y,p180,[]); %rotation                

                [t,A,r1]=r1.EvolutionConstH(H0,t_evol,[]);        
                out(in,:)=real(r1.Amplitudes(SOs));
            end 
        
        case "OPE-45-CPMG-CPRn"        
            print_progress(0)
            for in=1:n
                print_progress(in/n)
                [t,A,r1]=r1.EvolutionConstH(H0,t_evol,[]);  
                
                [t,A,r1]=r1.EvolutionConstH(H1_X,p90,[]); %rotation 
                [t,A,r1]=r1.EvolutionConstH(H1_Y,p180,[]); %rotation
                [t,A,r1]=r1.EvolutionConstH(H1_X,p90,[]); %rotation 
                
                [t,A,r1]=r1.EvolutionConstH(H0,t_evol,[]); 
                out(in,:)=real(r1.Amplitudes(SOs));
            end                                                                          
    end                                      
end

function [TE, out]=OPE(SOT,rin,tau,nechoes,H0,H1_X,H1_Y,SOs,p45,p90,p180)    
    TE = nechoes*2*tau; % total SOT time
    n_tau=length(tau);
    out=zeros(n_tau,length(SOs));
    [t,A,r0]=rin.EvolutionConstH(H1_Y,p45,[]); %rotation                 

    switch SOT.name
        case "OPE-45-Rn"                                                                       
            print_progress(0)
            for it=1:n_tau
                print_progress(it/n_tau)
                t_evol=tau(it);            
                r1=r0;
                for in=1:nechoes
                    [t,A,r1]=r1.EvolutionConstH(H0,t_evol,[]);  
    
                    [t,A,r1]=r1.EvolutionConstH(H1_Y,p180,[]); %rotation                
    
                    [t,A,r1]=r1.EvolutionConstH(H0,t_evol,[]);                            
                end
                out(it,:)=real(r1.Amplitudes(SOs));
            end

        case "OPE-45-CPRn"      
            print_progress(0)
            for it=1:n_tau
                print_progress(it/n_tau)
                t_evol=tau(it);            
                r1=r0;
                for in=1:nechoes                    
                    [t,A,r1]=r1.EvolutionConstH(H0,t_evol,[]);  
    
                    [t,A,r1]=r1.EvolutionConstH(H1_X,p90,[]); %rotation 
                    [t,A,r1]=r1.EvolutionConstH(H1_Y,p180,[]); %rotation
                    [t,A,r1]=r1.EvolutionConstH(H1_X,p90,[]); %rotation                
    
                    [t,A,r1]=r1.EvolutionConstH(H0,t_evol,[]);                            
                end
                out(it,:)=real(r1.Amplitudes(SOs));
            end
    end                                      
end

