%% start %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all; %clear all and delete all previous data
tic
p=LoadPath("AP");
%% change parameters here
System_ID=57; %"Eth-Acetate-d3-spin2" - 40; "Eth-Acetate-spin5" - 57;  "Acetone-spin1" - 58;
System=Load_System_Name(System_ID);
ex = Load_System(System);
%% spectral parameters
ex.B0=0.4396; % X,Y,Z Tesla
spec.Relaxation = "Off"; % "Off" or "DD", "LFF"
ex.Folder="out\spectrum_"+System+"_.mat";
spec.pulse  = pi/2                         ; % excitation pulse [rad]
spec.ph1    = 'Y'                          ; % excitation phase
spec.B0     = ex.B0                        ; % observation magnetic field [T]
spec.v0_1H  = spec.B0*ex.S.gamma{1}/(2*pi) ; % observation frequency, Hz
spec.SW     = 400                          ; % spectral width [Hz]
spec.TD     = 1024*16                      ; % number of points in FID

spec.v0               = spec.v0_1H         ; % observation frequency
spec.ppm0             = 0                  ; % main frequency and detection frequency in ppm

spec.FWHM             = 2                  ; % full width half maximum, artifitial broadening

%% initial state %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%InSt = "from_file"
InSt = "artificial";
Polarization=1;
switch InSt
    case "artificial"        
        r0   = DensityMatrix(ex.S.U/ex.S.Nstates + (3/ex.S.Nstates)*Polarization*ex.S.Dir("Z",1:ex.S.N)/(ex.S.SpinVal{1}+1)); % only longitudinal magnetization
    case "from_file"
        %in=load("out\SABRESHEATH_HH-2C-Pyruvate_B400nT_Kd1.mat");
        error('not implemented')             
end

%% calculate spectrum
Hc               = 2*pi*HZJij(ex.S,ex.PPM,ex.J,spec.B0,"full")   ; % calculate hamiltonian
r0 = r0.RotationSuperOperator(spec.pulse,spec.ph1,ex.S,ex.RegNuc); % execute excitation  
[spec.PPM, spec.FRQ, spec.SPEC] = r0.Spectrum(Hc,ex.S,spec.SW,spec.TD,spec.v0,spec.ppm0,ex.RegNuc,spec.FWHM,"-X")    ;
PlotSpec(spec.PPM,spec.SPEC,"PPM",System)  % plot the spectrum, to change to Hz, write spec.Hz and "Hz"                                         

SaveData('out\spectrum_'+System+'.txt',[spec.PPM spec.FRQ],[real(spec.SPEC) imag(spec.SPEC)]); % ppm, Hz, re, im
%%%%%%%%%%%%%%%%%%%%%%%%%% end %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
toc

