classdef SPIN
    %SPIN Summary of this class goes here
    %   Detailed explanation goes here
    
    properties
        
    end    
    properties (SetAccess = private)                
        Mx
        My
        Mz
        Mminus
        Mplus
        T1 %[s]
        T2 %[s]        
        M0 % equilibrium magnetization P*C
    end
    
    methods 
        function SP = SPIN(T,M0) % relaxation and concentration
            %SP.Mx=M(1);            
            %SP.My=M(2);
            %SP.Mz=M(3);
            SP.Mx     = 0                                                  ;                
            SP.My     = 0                                                  ;
            SP.Mz     = M0                                                 ;
            SP.Mminus = 0                                                  ;
            SP.Mplus  = 0                                                  ;

            if length(T)==1
                SP.T1 = T(1)                                               ;
                SP.T2 = T(1)                                               ;  
            elseif length(T)==2                
                SP.T1 = T(1)                                               ;
                SP.T2 = T(2)                                               ;        
            else 
                error("T longer than 2")                                   ;
            end
                        
            SP.M0       = M0                                               ;                                     
        end
        
        function [Time,Mout,S] = BLOCHe(S,w,time)                         %calculate evolution in ribbon (OX, sample) with gradient G                                                          
            Mic          = [S.Mx,S.My,S.Mz]                                ;                    
            [Time,Mout0] = ode45(@(t,M)Bloch(t,M,S.T1,S.T2,w,S.M0),time,Mic);                        

            Mout.Mx    = Mout0(:,1)                                        ;
            Mout.My    = Mout0(:,2)                                        ;
            Mout.Mz    = Mout0(:,3)                                        ;   
            Mout.Mplus = Mout.Mx + 1i*Mout.My                              ;
            Mout.Mplus = Mout.Mx - 1i*Mout.My                              ;
                        
            S = S.Set_Mxyz(Mout.Mx(end),Mout.My(end),Mout.Mz(end))         ;                 
        end
        
        function [Time,Mout,S] = BLOCHe_RD(S,time,w,tRD,D_RD,noiseRD)%calculate evolution in ribbon (OX, sample) with gradient G                       
                                    
            Mic           = [S.Mx,S.My,S.Mz]                               ;                    
            [Time,MoutRD] = ode45(@(t,M)Bloch_RD(t,M,S.T1,S.T2,tRD,D_RD,noiseRD,w,S.M0),time,Mic);

            Mout.Mx    = MoutRD(:,1)                                       ;
            Mout.My    = MoutRD(:,2)                                       ;
            Mout.Mz    = MoutRD(:,3)                                       ;   
            Mout.Mplus = Mout.Mx + 1i*Mout.My                              ;
            Mout.Mplus = Mout.Mx - 1i*Mout.My                              ;
                                    
            S=S.Set_Mxyz(Mout.Mx(end),Mout.My(end),Mout.Mz(end)); 
        end
        
        function SP = IdealRotation(obj,angle,dir)
            SP  = obj                                                      ;
            if startsWith(dir, '-')
               angle = - angle                                             ;   
               dir   = dir(2:end)                                          ; % Remove the '-' from the direction 
            end
            c   = cos(angle)                                               ;
            s   = sin(angle)                                               ;
            switch dir
                case {'X','x'}             
                    SP.Mx = obj.Mx                                         ;
                    SP.My = obj.My*c - s*obj.Mz                            ;
                    SP.Mz = obj.My*s + c*obj.Mz                            ;                
                case {'Y','y'}                    
                    SP.Mx = obj.Mx*c + s*obj.Mz                            ;
                    SP.My = obj.My                                         ;
                    SP.Mz = obj.Mx*(-s)+ c*obj.Mz                          ;                
                case {'Z','z'}
                    SP.Mx = obj.Mx*c - s*obj.My                            ;
                    SP.My = obj.Mx*s + c*obj.My                            ;
                    SP.Mz = obj.Mz                                         ;                
                otherwise
                    error('we do not support such direction. You can add it yourown. We have only ''X'', ''Y'', ''Z'' directions');

            end                        
            SP.Mplus = SP.Mx+1i*SP.My                                      ;
            SP.Mminus = conj(SP.Mplus)                                     ;
        end
        
        function SP = BLOCH_wz(obj,wz,t)
            SP = obj                                                       ;
            if length(t)~=1
                error('length of time should be 1')                        ;
            end
            if length(wz)~=1
                error('length of w0z should be 1')                         ;
            end
                                                                          
            SP.Mplus = obj.Mplus*exp((-1i*wz-1/obj.T2)*t)                  ;
            SP.Mplus = conj(SP.Mplus)                                      ;
            SP.Mx    = real(SP.Mplus)                                      ;
            SP.My    = imag(SP.Mplus)                                      ;
            SP.Mz    = (obj.Mz-obj.M0)*exp(-t/obj.T1) + obj.M0             ;                    
        end
        
        
        function [Mout,S] = BLOCHe_wz(S,Time,wz)            
            if length(Time)==1
                error('length of time should be more than 1')              ;
            end
            if length(wz)~=1
                error('length of w0z should be 1')                         ;
            end
            m=size(Time)                                                   ;
            if m(1)<m(2)
                Time = Time'                                               ;
            end
                                                 
           Mout.Mplus  = S.Mplus*exp((-1i*wz-1/S.T2)*Time)                 ;                                  
           Mout.Mminus = conj(Mout.Mplus)                                  ;
           Mout.Mx     = real(Mout.Mplus)                                  ;
           Mout.My     = imag(Mout.Mplus)                                  ;           
           Mout.Mz     = (S.Mz-S.M0).*exp(-Time/S.T1) + S.M0               ;                      

           S = S.Set_Mxyz(Mout.Mx(end),Mout.My(end),Mout.Mz(end))          ;           
        end
        
        function SP = Set_Mxyz(SP,Mx,My,Mz)
                SP.Mx     = Mx                                             ;
                SP.My     = My                                             ;
                SP.Mz     = Mz                                             ;
                SP.Mplus  = Mx + 1i*My                                     ;
                SP.Mminus = Mx - 1i*My                                     ;
        end
                       
        function SP = RemoveCoherences(SP)
           SP.Mx      = 0                                                  ;
           SP.My      = 0                                                  ;
           SP.Mminus  = 0                                                  ;
           SP.Mplus   = 0                                                  ;
        end
    end
end            
        
        
        
    
    


