classdef SPINS
    %SPINS Summary of this class goes here
    %   Detailed explanation goes here
    
    properties
        N
        SPIN
    end
    
    methods
        function SPS = SPINS(varargin)
            if isequal(class(varargin{1}),'SPIN')
                for k = 1:length(varargin)
                    if ~isequal(class(varargin{k}),'SPIN')
                        display(varargin{k})                               ;
                        disp("not class SPIN!")
                    end
                end  
                SPS.N = length(varargin)                                   ;
                SPS.SPIN = cell(SPS.N,1)                                   ;
                for k = 1:SPS.N
                    SPS.SPIN{k} = varargin{k}                              ;
                end            
            else
                if length(varargin)==3
                    T1 = varargin{1}                                       ;
                    T2 = varargin{2}                                       ;                    
                    C  = varargin{3}                                       ;
                    SPS.N = length(T1)                                     ;
                    for k = 1:SPS.N
                        SPS.SPIN{k} = SPIN([T1(k),T2(k)],C(k))             ;
                    end            
                else 
                    error
                end
            end
        end
        
        function outputArg = method1(obj,inputArg)
            %METHOD1 Summary of this method goes here
            %   Detailed explanation goes here
            outputArg = obj.Property1 + inputArg                           ;
        end
%% operations with SPINS

        function SPS = IdealRotation(SPS,phi,dir,varargin)
            % SPS = spins
            % phi is flippling angle
            % dir is phase of the excitation X,Y,Z
            % varargin{1} specifies the spins to be excited
            if nargin==3
                for k = 1:SPS.N
                    SPS. SPIN{k} = SPS. SPIN{k}.IdealRotation(phi,dir)     ;
                end            
            elseif nargin==4
                Ex = varargin{1}                                           ;
                for k = 1:length(Ex)
                    SPS.SPIN{Ex(k)} = SPS.SPIN{Ex(k)}.IdealRotation(phi,dir);
                end
            else
                error                                                      ;
            end
        end
        
        function SPS = RemoveCoherences(SPS)
            for k = 1:SPS.N
                SPS.SPIN{k}=SPS.SPIN{k}.RemoveCoherences();
            end
        end

        function [Me,SPS] = BLOCHe_wz(SPS,time,wz)
            Me = cell(SPS.N,1)                                             ;
            for k = 1:SPS.N
                [Me{k},SPS.SPIN{k}] = SPS.SPIN{k}.BLOCHe_wz(time,wz(k))    ;                
            end
        end

        function [Time, Me,SPS] = BLOCHe_wz_RD(SPS,time,wz,tRD,D_RD,noiseRD)
            Me = cell(SPS.N,1)                                             ;
            for k = 1:SPS.N
                [Time, Me{k}, SPS.SPIN{k}] = SPS.SPIN{k}.BLOCHe_RD(time,[0,0,wz(k)],tRD,D_RD,noiseRD);                
            end
        end

        function [Me,SPS] = BLOCHe_wzExchange(SPS,Time,Spec)                                    

            m = size(Time)                                                 ;
            if m(1)<m(2)
                Time = Time'                                               ;
            end
           
            KT       = Spec.K                                              ;
            KL       = Spec.K                                              ;
            Mplus0   = zeros(SPS.N,1)                                      ; % initial state
            Mz0      = zeros(SPS.N,1)                                      ; % initial state
            MzeqT1   = zeros(SPS.N,1)                                      ; % equilibrium magnetizationion over T1
            for n = 1:SPS.N
                KT(n,n)   = KT(n,n)-1i*(Spec.wz(n)-Spec.o1)-1/SPS.SPIN{n}.T2         ;
                KL(n,n)   = KL(n,n)-1/SPS.SPIN{1}.T1                       ;        
                Mplus0(n) = SPS.SPIN{n}.Mplus                              ; % initial Mplus
                Mz0(n)    = SPS.SPIN{n}.Mz                                 ; % initial Mz
                MzeqT1(n) = SPS.SPIN{1}.M0/SPS. SPIN{1}.T1                 ; % M0/T1
            end                                    
            KLRMzeq       = -KL\MzeqT1                                     ; % equilibrium K\Mz0/T1
            

            Mout.Mplus    = zeros(SPS.N,length(Time))                      ;
            Mout.Mz       = zeros(SPS.N,length(Time))                      ;            
            for it = 1:length(Time)
                t  = Time(it)                                              ;
                Mout.Mplus(:,it) = expm(KT*t)*Mplus0                       ;                       
                Mout.Mz(:,it)    = expm(KL*t)*(Mz0-KLRMzeq)+ KLRMzeq       ;              
            end
            Mout.Mplus     = transpose(Mout.Mplus)                         ;
            Mout.Mminus    = conj(Mout.Mplus)                              ;
            Mout.Mz        = transpose(Mout.Mz)                            ;
            Mout.Mx        = real(Mout.Mplus)                              ;
            Mout.My        = imag(Mout.Mplus)                              ;            
            
            Me               = cell(SPS.N,1)                               ;
                                              
            for k = 1:SPS.N
                SPS.SPIN{k}  = SPS.SPIN{k}.Set_Mxyz(Mout.Mx(end,k),Mout.My(end,k),Mout.Mz(end,k));

                Me{k}.Mx     = Mout.Mx(:,k)                                ;
                Me{k}.My     = Mout.My(:,k)                                ;
                Me{k}.Mz     = Mout.Mz(:,k)                                ;
                Me{k}.Mplus  = Mout.Mplus(:,k)                             ;
                Me{k}.Mminus = Mout.Mminus(:,k)                            ;
            end
        end
%% pulse sequences 1D
    function Spec = zg(~,Spec)
        Spec.time           = (0:Spec.td-1)'/Spec.sw                       ; % Time vector
        Spec.aq             = Spec.time(end)                               ; % Total acquisition time

        Spec.M              = Spec.M.IdealRotation(Spec.p1*pi/180,Spec.ph1);
        [Spec.Mevol,Spec.M] = Spec.M.BLOCHe_wz(Spec.time,Spec.wz)          ; % calculate evolution
        Spec.Signal{1}      = Spec.M.Signal_1D(Spec,'X')                   ;
    end
    
    function Spec = zg_RD(~,Spec)
        Spec.time           = (0:Spec.td-1)'/Spec.sw                       ; % Time vector
        Spec.aq             = Spec.time(end)                               ; % Total acquisition time

        Spec.M              = Spec.M.IdealRotation(Spec.p1*pi/180,Spec.ph1);  
       %Spec.M              = Spec.M.RemoveCoherences()                    ; % optional        
        [Time,Spec.Mevol,Spec.M] = Spec.M. BLOCHe_wz_RD(Spec.time,Spec.wz,Spec.tauRD,Spec.D_RD,Spec.noiseRD)           ; % calculate evolution
        Spec.Signal         = Spec.M.Signal_1D(Spec,'X')                   ;
    end
    
    function Spec = zg_Ex(~,Spec)
        Spec.time           = (0:Spec.td-1)'/Spec.sw                       ; % Time vector
        Spec.aq             = Spec.time(end)                               ; % Total acquisition time

        [~,Spec.M]          = Spec.M.BLOCHe_wzExchange(Spec.time2relax,Spec); % free evolution
        Spec.M              = Spec.M.IdealRotation(Spec.p1*pi/180,Spec.ph1);
        % evolution during timeFID
        [Spec.Mevol,Spec.M] = Spec.M. BLOCHe_wzExchange(Spec.time,Spec)    ; % calculate evolution
        Spec.Signal         = Spec.M.Signal_1D(Spec,'X')                   ;
    end
        
%% pulse sequences pseudo 1D
    function [Spec, M]  = SEXY(M,Spec)
            Spec.time       = (0:Spec.td-1)'/Spec.sw                       ; % Time vector
            Spec.aq         = Spec.time(end)                               ; % Total acquisition time


            [Spec.Mevol,M]  = M.BLOCHe_wzExchange(Spec.time2relax,Spec)    ; % Calculate evolution
            Spec.Integrals  = zeros(length(Spec.time_mix),M.N)             ; % Here integrals of the spectral linex will be 
            Spec.N_spec     = length(Spec.time_mix)                        ; % number of spectra
            % Dummy scans
            for id = 1:Spec.ds                
                % SEXY sequence
                 [~,M] = M.BLOCHe_wzExchange(Spec.d1,Spec)                 ; % Calculate evolution
                     M = M.IdealRotation(pi,'Y',Spec.selective_excitation) ; % 180 selective rotation
                 [~,M] = M.BLOCHe_wzExchange(Spec.time_mix(1),Spec)        ; % Calculate evolution
                     M = M.IdealRotation(pi/2,'Y')                         ; % 90-Y rotation
                % Evolution during timeFID
                
                temp           = Spec.o1                                   ;
                Spec.o1        = Spec.o1*0                                 ;
                [Spec.Mevol,M] = M.BLOCHe_wzExchange(Spec.time(end),Spec)  ; % Calculate evolution           
                          M = M.RemoveCoherences()                         ; % Remove coherences which were left from the previous experiment   
                Spec.o1         = temp                                     ; % reset o1 value          
                          
            end
            % Real scans
            print_progress(0)                                              ;
            for id = 1:length(Spec.time_mix)
                print_progress(id/length(Spec.time_mix))
                 Spec.Signal{id} = zeros(Spec.td,1)                        ;
                % SEXY sequence
                [~,M] = M.BLOCHe_wzExchange(Spec.d1,Spec)                  ; % calculate evolution
                    M = M.IdealRotation(pi,'Y',Spec.selective_excitation)  ; % 180 selective rotation
                [~,M] = M.BLOCHe_wzExchange(Spec.time_mix(id),Spec)        ; % calculate evolution
                    M = M.IdealRotation(pi/2,'Y')                          ; % 90-Y rotation
                % evolution during timeFID
                [Spec.Mevol,M] = M.BLOCHe_wzExchange(Spec.time,Spec)       ; % calculate evolution            
                             M = M.RemoveCoherences()                      ; % remove coherences which were left from the previous experiment
                % end of the one experimental cycle
                temp            = Spec.o1                                  ;
                Spec.o1         = Spec.o1*0                                ;
                Spec.Signal{id} = Spec.Signal{id} + Signal_1D(M,Spec,'X')  ;
                Spec.o1         = temp                                     ; % reset o1 value
            end
    end
        
    %% pulse sequences pseudo 1D
   
     function [Spec, M]  = selno_PC(M,Spec)
            Spec.time       = (0:Spec.td-1)'/Spec.sw                       ; % Time vector
            Spec.aq         = Spec.time(end)                               ; % Total acquisition time
          % selno D1-S90-D14-90-Dmix-90-FID
            [Spec.Mevol,M]  = M.BLOCHe_wzExchange(Spec.time2relax,Spec)    ; % Calculate evolution
            Spec.Integrals  = zeros(length(Spec.time_mix),M.N)             ; % Here integrals of the spectral linex will be 
            Spec.N_spec     = length(Spec.time_mix)                        ; % number of spectra
            ph1 = {'X','-X','X','-X','X','-X','X','-X','X','-X','X','-X','X','-X','X','-X',}     ; 
            ph2 = {'X','X','X','X','X','X','X','X','-X','-X','-X','-X','-X','-X','-X','-X'}      ;
            ph3 = {'X','X','-X','-X','Y','Y','-Y','-Y','X','X','-X','-X','Y','Y','-Y','-Y'}      ; 
            phrec = {'X','-X','-X','X','Y','-Y','-Y','Y','-X','X','X','-X','-Y','Y','Y','-Y'}    ;
        
            % Dummy scans
            for id = 1:Spec.ds
                % SEXY:selno sequence
                 [~,M] = M. BLOCHe_wzExchange(Spec.d1,Spec)                ; % Calculate evolution
                     M = M.IdealRotation(pi/2,'Y',Spec.selective_excitation) ; % 90 selective rotation
                 [~,M] = M.BLOCHe_wzExchange(Spec.d14,Spec)                ; % Calculate evolution
                     M = M.IdealRotation(pi/2,'Y')                         ; % 90-X rotation
                 [~,M] = M.BLOCHe_wzExchange(Spec.time_mix(1),Spec)        ; % Calculate evolution
                     M = M.IdealRotation(pi/2,'Y')                         ; % 90-X rotation    
                
                     % Evolution during timeFID
                     % during FID do not use rotating frame o1
                temp           = Spec.o1                                   ;
                Spec.o1        = Spec.o1*0                                 ;
                [Spec.Mevol,M] = M.BLOCHe_wzExchange(Spec.aq,Spec)         ; % Calculate evolution           
                             M = M.RemoveCoherences()                      ; % Remove coherences which were left from the previous experiment                
                Spec.o1        = temp                                      ; % reset o1 value
            end            
            
            print_progress(0)                                              ;
            for id = 1:length(Spec.time_mix)
                  print_progress(id/length(Spec.time_mix))
                  Spec.Signal{id}= zeros(Spec.td,1)                        ;
              for i_s = 1:Spec.ns
                % SEXY sequence
                [~,M] = M. BLOCHe_wzExchange(Spec.d1,Spec)                 ; % calculate evolution
                    M = M.IdealRotation(pi/2,ph1{i_s},Spec.selective_excitation); % 90 selective rotation
                [~,M] = M.BLOCHe_wzExchange(Spec.d14,Spec)                 ; % Calculate evolution
                    M = M.IdealRotation(pi/2,ph2{i_s})                     ; % 90-X rotation
                [~,M] = M.BLOCHe_wzExchange(Spec.time_mix(id),Spec)        ; % Calculate evolution
                    M = M.IdealRotation(pi/2,ph3{i_s})                     ; % 90-X rotation
                % evolution during timeFID
                % during FID do not use rotating frame o1
                temp            = Spec.o1                                  ;
                Spec.o1         = Spec.o1*0                                ;
                [Spec.Mevol,M]  = M.BLOCHe_wzExchange(Spec.time,Spec)      ; % calculate evolution
                Spec.Signal{id} = Spec.Signal{id} + Signal_1D(M,Spec,phrec{i_s}) ;
                         M = M.RemoveCoherences()                          ; % remove coherences which were left from the previous experiment
                Spec.o1         = temp                                     ; % reset o1 value
                % end of the one experimental cycle
              end
           end
     end
       
%% pulse sequence selnogpzs.2      
       function [Spec, M]  = selnogpzs(M,Spec)
            Spec.time       = (0:Spec.td-1)'/Spec.sw                       ; % Time vector
            Spec.aq         = Spec.time(end)                               ; % Total acquisition time

            [Spec.Mevol,M]  = M.BLOCHe_wzExchange(Spec.time2relax,Spec)    ; % Calculate evolution
            Spec.Integrals  = zeros(length(Spec.time_mix),M.N)             ; % Here integrals of the spectral linex will be 
            Spec.N_spec     = length(Spec.time_mix)                        ; % number of spectra
            ph1 = {'X','-X','X','-X', 'X','-X', 'X','-X'}                  ; 
            ph2 = {'X', 'X','Y', 'Y','-X','-X','-Y','-Y'}                  ;
            ph3 = {'X', 'X','X', 'X', 'X', 'X', 'X', 'X'}                  ; 
            ph4 = {'X', 'X','X', 'X', 'X', 'X', 'X', 'X'}                  ;
            ph5 = {'X', 'X','X', 'X', 'X', 'X', 'X', 'X'}                  ; 
            phrec = {'-X','X','X','-X','-X','X','X','-X'}                  ;
        
            % Dummy scans
            for id = 1:Spec.ds
                % SEXY:selnogpzs.2 sequence
                 [~,M] = M. BLOCHe_wzExchange(Spec.d1,Spec)                ; % Calculate evolution
                     M = M.IdealRotation(pi/2,'X',Spec)                    ; % 90 rotation
                                                                             % gradient 
                 [~,M] = M.BLOCHe_wzExchange(Spec.d16,Spec)                ; % Calculate evolution
                     M = M.IdealRotation(pi,'X',Spec.selective_excitation) ; % Gaus1_180r.1000
                                                                             % gradient
                 [~,M] = M.BLOCHe_wzExchange(Spec.d16,Spec)                ; % Calculate evolution
                     M = M.IdealRotation(pi/2,'X')                         ; % 90-X rotation 
                 [~,M] = M.BLOCHe_wzExchange(0.31*Spec.d20,Spec)           ; % Calculate evolution d20*0.49   
                                                                             % gradient
                 [~,M] = M.BLOCHe_wzExchange(Spec.d16,Spec)                ; % Calculate evolution
                     M = M.IdealRotation(pi/2,'X')                         ; % bip720.50.20.1
                                                                             % gradient
                 [~,M] = M.BLOCHe_wzExchange(Spec.d16,Spec)                ; % Calculate evolution
                 [~,M] = M.BLOCHe_wzExchange(0.49*Spec.d20,Spec)           ; % Calculate evolution d20*0.49
                                                                             % gradient 2 times
                 
                 [~,M] = M.BLOCHe_wzExchange(Spec.d16,Spec)                ; % Calculate evolution
                     M = M.IdealRotation(pi/2,'X')                         ; % crp60.20.20.10
                     
                 [~,M] = M.BLOCHe_wzExchange(Spec.d16,Spec)                ; % Calculate evolution    
                                                                             % gradient 2 times
                 [~,M] = M.BLOCHe_wzExchange(Spec.d16,Spec)                ; % Calculate evolution
                 [~,M] = M.BLOCHe_wzExchange(0.2*Spec.d20,Spec)            ; % Calculate evolution
                     M = M.IdealRotation(pi/2,'X')                         ; % 90-X rotation                                                            
                
                     % Evolution during timeFID
                     % during FID do not use rotating frame o1
                temp           = Spec.o1                                   ;
                Spec.o1        = Spec.o1*0                                 ;
                [Spec.Mevol,M] = M.BLOCHe_wzExchange(Spec.aq,Spec)         ; % Calculate evolution           
                             M = M.RemoveCoherences()                      ; % Remove coherences which were left from the previous experiment                
                Spec.o1        = temp                                      ; % reset o1 value
            end            
            
            print_progress(0)                                              ;
            for id = 1:length(Spec.time_mix)
                  if Spec.time_mix(id) > Spec.dall
                      Spec.d20 = Spec.time_mix(id)-Spec.dall               ;
                  else 
                      Spec.d20 = 3e-06                                     ;
                  end
                  print_progress(id/length(Spec.time_mix))
                  Spec.Signal{id}= zeros(Spec.td,1)                        ;
              for i_s = 1:Spec.ns
                % SEXY sequence
                 [~,M] = M. BLOCHe_wzExchange(Spec.d1,Spec)                ; % Calculate evolution
                     M = M.IdealRotation(pi/2,ph1{i_s},Spec)               ; % 90 rotation
                                                                             % gradient 
                 [~,M] = M.BLOCHe_wzExchange(Spec.d16,Spec)                ; % Calculate evolution
                     M = M.IdealRotation(pi,ph2{i_s},Spec.selective_excitation) ; % Gaus1_180r.1000
                                                                             % gradient
                 [~,M] = M.BLOCHe_wzExchange(Spec.d16,Spec)                ; % Calculate evolution
                     M = M.IdealRotation(pi/2,ph3{i_s})                    ; % 90-X rotation 
                 [~,M] = M.BLOCHe_wzExchange(0.31*Spec.d20,Spec)           ; % Calculate evolution d20*0.49   
                                                                             % gradient
                 [~,M] = M.BLOCHe_wzExchange(Spec.d16,Spec)                ; % Calculate evolution
                     M = M.IdealRotation(pi/2,ph4{i_s})                    ; % bip720.50.20.1
                                                                             % gradient
                 [~,M] = M.BLOCHe_wzExchange(Spec.d16,Spec)                ; % Calculate evolution
                 [~,M] = M.BLOCHe_wzExchange(0.49*Spec.d20,Spec)           ; % Calculate evolution d20*0.49
                                                                             % gradient 2 times
                 
                 [~,M] = M.BLOCHe_wzExchange(Spec.d16,Spec)                ; % Calculate evolution
                     M = M.IdealRotation(pi/2,ph4{i_s})                    ; % crp60.20.20.10
                     
                 [~,M] = M.BLOCHe_wzExchange(Spec.d16,Spec)                ; % Calculate evolution    
                                                                             % gradient 2 times
                 [~,M] = M.BLOCHe_wzExchange(Spec.d16,Spec)                ; % Calculate evolution
                 [~,M] = M.BLOCHe_wzExchange(0.2*Spec.d20,Spec)            ; % Calculate evolution
                     M = M.IdealRotation(pi/2,ph5{i_s})                    ; % 90-X rotation  
               
                % evolution during timeFID
                % during FID do not use rotating frame o1
                temp            = Spec.o1                                  ;
                Spec.o1         = Spec.o1*0                                ;
                [Spec.Mevol,M]  = M.BLOCHe_wzExchange(Spec.time,Spec)      ; % calculate evolution
                Spec.Signal{id} = Spec.Signal{id} + Signal_1D(M,Spec,phrec{i_s}) ;
                         M = M.RemoveCoherences()                          ; % remove coherences which were left from the previous experiment
                Spec.o1         = temp                                     ; % reset o1 value
                % end of the one experimental cycle
              end
           end
        end
%% pulse sequences 2D
                              
         function [Spec, M] = noesyph(M,Spec)
             
           Spec.time      = (0:Spec.td-1)'/Spec.sw                         ; % Time vector
           Spec.d0        = (0:Spec.td1-1)'/Spec.sw1                       ; % Time vector you can use incermented d0
           % noesyph D1-90-D0-90-D8-90-FID
            ph1 = {'X','-X','X','-X','X','-X','X','-X','X','-X','X','-X','X','-X','X','-X',}     ; 
            ph2 = {'X','X','X','X','X','X','X','X','-X','-X','-X','-X','-X','-X','-X','-X'}      ;
            ph3 = {'X','X','-X','-X','Y','Y','-Y','-Y','X','X','-X','-X','Y','Y','-Y','-Y'}      ; 
            phrec = {'X','-X','-X','X','Y','-Y','-Y','Y','-X','X','X','-X','-Y','Y','Y','-Y'}    ;
        
            % dummy scans
            for tds = 1:Spec.ds
                [~,M] = M.BLOCHe_wzExchange(Spec.d1,Spec)                  ; % calculate evolution    
                         M = M.IdealRotation(pi/2,'X')                     ;
                [~,M] = M.BLOCHe_wzExchange(Spec.d0(1),Spec)               ; % calculate evolution
                         M = M.IdealRotation(pi/2,'X')                     ;
                [~,M] = M.BLOCHe_wzExchange(Spec.d8,Spec)                  ; % calculate evolution
                         M = M.IdealRotation(pi/2,'X')                     ;
                         
                temp           = Spec.o1                                   ;
                Spec.o1        = Spec.o1*0                                 ;
                [Spec.Mev,M]   = M.BLOCHe_wzExchange(Spec.time(end),Spec)  ; % calculate evolution
                M              = M.RemoveCoherences()                      ;
                Spec.o1        = temp                                      ; % reset o1 value
            end
            % real scans
            print_progress(0) 
            Spec.Signal = zeros(Spec.td,Spec.td1)                          ;
            for id = 1:Spec.td1 
               print_progress(id/Spec.td1)               
               for i_s = 1:Spec.ns               
                    [~,M] = M.BLOCHe_wzExchange(Spec.d1,Spec)              ; % calculate evolution    
                             M = M.IdealRotation(pi/2,ph1{i_s})            ;
                    [~,M] = M.BLOCHe_wzExchange(Spec.d0(id),Spec)          ; % calculate evolution
                             M = M.IdealRotation(pi/2,ph2{i_s})            ;
                    [~,M] = M.BLOCHe_wzExchange(Spec.d8,Spec)              ; % calculate evolution
                             M = M.IdealRotation(pi/2,ph3{i_s})            ;
                    % evolution during timeFID
                    % during FID do not use rotating frame o1         
                    temp                  = Spec.o1                        ;
                    Spec.o1               = Spec.o1*0                      ;
                    [Spec.Mevol,M] = M.BLOCHe_wzExchange(Spec.time,Spec)   ; % calculate evolution                                                                   
                    Spec.Signal(:,id) = Spec.Signal(:,id) + Signal_1D(M,Spec,phrec{i_s}) ;   
                                        M = M.RemoveCoherences()           ;
                    Spec.o1               = temp                           ; % reset o1 value
                end                
            end
            % for State TPPPI?
            % for i_td1 = 1:Spec.td1  
            %     Spec.Signal(:,i_td1) = Spec.Signal(:,i_td1)*(-1)^i_td1   ;
            % end

        end


%% signal acquisition 1D
        function Signal = Signal_1D(SPS,Spec,ph)
           Signal = 0                                                      ;
           switch ph
               case "X"
                   for k = 1:Spec.M.N
                        Signal = Signal + Spec.Mevol{k}.Mx                 ; 
                   end
              case "-X"
                   for k = 1:Spec.M.N
                        Signal = Signal - Spec.Mevol{k}.Mx                 ; 
                   end
              case "Y"
                   for k = 1:Spec.M.N
                        Signal = Signal + Spec.Mevol{k}.My                 ; 
                   end
              case "-Y"
                   for k = 1:Spec.M.N
                        Signal = Signal - Spec.Mevol{k}.My                 ; 
                   end
               otherwise
                   error("only X,-X,Y and -Y are suppported")
           end
        end

        % Signal 1D processing
        function Spec = proc_1D(SPS,Spec,id)
            % calculates spectrum and integrals
            Spec = SPS.Spectrum(Spec,id)                                   ; % calculate spectrum                               
              for id_spin = 1:SPS.N                    
                  [Spec.Integrals(id,id_spin),~,~] = D1_integral(Spec.Proc.frq,Spec.Proc.Spectrum{id},Spec.Integrals_range(id_spin,:));
              end
        end

        function Spec = proc_all_1D(SPS,Spec)
            % ADD LINEBROADENING, ADD PHASE OF THE SPECTRUM
            for id = 1:Spec.N_spec
                Spec = proc_1D(SPS,Spec,id)                                ;
            end  
        end


        function Spec   = Spectrum(SPS,Spec,id)
            % zero filling
            % line broadening
            % phase correction

            % varargin{1} is spec id
                    
            Spec.Proc.Signal{id}            = zeros (1, Spec.si)           ;
            Spec.Proc.Signal{id}(1:Spec.td) = Spec.Signal{id}.*exp(-Spec.lb*Spec.time)*exp(1i*Spec.ph0*pi/180)       ; % linebroadening  and phase correction
            Spec.Proc.time                  = (0:Spec.si-1)'/Spec.sw       ;
            FFTSignal            = ((fft(Spec.Proc.Signal{id})))/Spec.si   ;
            
            % FID    half of the spectrum
            Spec.Proc.frq        = Spec.sw*(0:(Spec.si/2))/Spec.si         ; % frequency domain 
            Spectrum             = FFTSignal(1:Spec.si/2+1)                ;
            Spectrum(2:end-1)    = 2*Spectrum(2:end-1)                     ;            
            Spec.Proc.Spectrum{id} = Spectrum                              ;


%             % FID    half of the spectrum
%             Spec.Proc.frq        = Spec.sw*(-(Spec.si/2)+1:(Spec.si/2))/Spec.si         ; % frequency domain  
%             Spectrum             = fftshift(FFTSignal)                   ;
%             Spec.Proc.Spectrum{id} = Spectrum                            ;
            
        end

        function Spec = Plot_Spectrum(SPS,Spec,id)
            figure("color","white")
            subplot(2,1,1)
            plot(Spec.time,real(Spec.Signal{id}))
            hold on                                                        ;
            plot(Spec.Proc.time,real(Spec.Proc.Signal{id}),'r')
            title ('FID')
            legend ('Signal', 'Proccessed Signal')
            xlabel('Time (s)')
            hold off                                                       ;
            subplot(2,1,2)
            plot(Spec.Proc.frq,real(Spec.Proc.Spectrum{id}),'r')
            title ('Spectrum')
            xlabel('Frequency (Hz)')
        end

        function Spec = Plot_Spectra(SPS,Spec)
            figure("color","white")
            
            subplot(2,1,1)
            for k = 1:length(Spec.Proc.Spectrum)
                plot(Spec.Proc.time,real(Spec.Proc.Signal{k}))
                xlabel('Time (s)')
            end

            subplot(2,1,2)
            for k = 1:length(Spec.Proc.Spectrum)
                plot(Spec.Proc.frq,real(Spec.Proc.Spectrum{k}))
                hold on
            end
            hold off
            xlabel('Frequency (Hz)')
            
            % subplot(2,2,4)
            % for k = 1:length(Spec.Proc.Spectrum)
            %     plot(Spec.Proc.frq,imag(Spec.Proc.Spectrum{k}))
            %     hold on
            % end
            % hold off
            % xlabel('Frequency (Hz)')
        end

%% signal processing 2D
%         function Signal = Signal_2D(SPS,Spec)
%             Signal = zeros(Spec.td,Spec.td1)                               ;
%             for id = 1:Spec.td1                
%                  for k = 1:SPS.N
%                      Signal(:,id) = Signal(:,id)+ Spec.ML1{id}{k}.Mx       ;
%                  end                
%            end
%         end
                                
        function Spec   = proc_2D(SPS,Spec)
            % FID 
            Spec.frq    = Spec.sw*(0:(Spec.si/2))/Spec.si                  ; % frequency domain
            Spec.frq1   = Spec.sw1*(0:(Spec.si1/2))/Spec.si1               ; % frequency domain
            Spec.Proc.Signal            = zeros (Spec.si, Spec.si1)        ; % Initialize the processed signal matrix
            Spec.Proc.Signal(1:Spec.td,1:Spec.td1) = Spec.Signal.*(exp(-Spec.lb*Spec.time)*exp(-Spec.lb1*Spec.d0)')      ; % linebroadening %%%%%% *exp(1i*Spec.ph0*pi/180)
            FFTSignal   = (fft2(Spec.Proc.Signal))/(Spec.si*Spec.si1)      ;
            Spectrum    = FFTSignal(1:Spec.si/2+1,1:Spec.si1/2+1)          ;
            Spec.Spectrum = Spectrum.*exp(1i*(Spec.ph0 + Spec.ph1*(0:Spec.frq)))  ; %%%%%%%%%%%%%%%%%%%%%%% zero and first order phase correction
            [Spec.frq_2D, Spec.frq1_2D] = meshgrid(Spec.frq1,Spec.frq)     ;
            [Spec.time_2D, Spec.d0_2D]  = meshgrid(Spec.d0,Spec.time)      ;  % Create 2D grids
             

        end
             
        function Plot_Spectrum2D(M,Spec)
            fig      = figure('color','white','DefaultAxesFontSize',20,'Position',[100,100,600,900]);
            subplot(2,1,1)
            %fontsize(fig, 44, "points")
            s        = surf(Spec.d0_2D,Spec.time_2D,abs((Spec.Signal)))    ;
            s.EdgeColor = 'none'                                           ;
            %s=contourf(Spec.d0_2D,Spec.time_2D,abs((Spec.Signal)))    ;
            xlabel("Time direct (s)")
            ylabel("Time indirect (s)")
            colormap("parula")                                             ;
            hcb         = colorbar                                         ;
            axis equal
            axis square
            view(2)
            box on
            
            subplot(2,1,2)
            %fontsize(fig, 44, "points")
            %s      = surf(Spec.frq1_2D,Spec.frq_2D,abs((Spec.Spectrum)))   ;
            %s.EdgeColor = 'none'                                           ;
            s = contourf(Spec.frq1_2D,Spec.frq_2D,abs((Spec.Spectrum)))    ;
            xlabel("Frequency direct (Hz)")
            ylabel("Frequency indirect (Hz)")
            
            colormap(parula(10))                                           ;
            hcb        = colorbar                                          ;
            axis equal
            axis square
            view(2)
            box on
        end


       


        




        
    end
end

