function Yout = sabre_ideal_ADAPT_RFt(ex)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% nonpolorized initial spin state of the Ir-complex and substrate
    rC0=DensityMatrix(ex.Sc.U);
    rS0=DensityMatrix(ex.Ss.U);
    rS=rS0;
    rC=rC0;
            
    NS2=ex.Ss.Nstates^2;
    NC2=ex.Sc.Nstates^2;
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% relaxation superoperator of the Ir-complex and substrate
    RsC=RLFF_EN(ex.Sc,ex.T1C);
    RsS=RLFF_EN(ex.Ss,ex.T1S);
    %% Yout matrix %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    Zero=zeros(length(ex.Dav),length(ex.RFv)); %zero matrix for data output
    Yout{1}=Zero;Yout{2}=Zero;Yout{3}=Zero;
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% calculate ADAPT-SABRE experiment         
    HsB=2*pi*HZJij(ex.Ss,ex.ppmS,ex.JS,ex.B0,"full");
    HcB=2*pi*HZJij(ex.Sc,ex.ppmC,ex.JC,ex.B0,"full");
    
    RotationS=-1i*H2Super(ex.Ss.OneDirectionOfSpins("X",ex.Ss.Xspins));
    RotationC=-1i*H2Super(ex.Sc.OneDirectionOfSpins("X",ex.Sc.Xspins));
    LRotation=[RotationS      zeros(NS2,NC2);
              zeros(NC2,NS2) RotationC];
    
    
    SABRE=SABRE_MOD2_matrix(rC0,...
            ex.Ss,HsB,RsS,...
            ex.Sc,HcB,RsC,...
            ex.Sh,...
            ex.fpH,ex.Wa,ex.Kd);
        
    vecS0=mtz2vec(rS0.val)/trace(rS0.val)*SABRE.fs;
    vecC0=mtz2vec(rC0.val)/trace(rC0.val)*SABRE.fc;
    vec0=[vecS0' vecC0']'; 
            
    for iRF=1:length(ex.RFv)
        disp(iRF/length(ex.RFv)*100);
        RF=ex.RFv(iRF);
        Rot=expm(LRotation*RF);
        %(-1i*Op*RF)
        % delay       
        for it=1:length(ex.Dav)
            t=ex.Dav(it);
            vec=((expm(SABRE.A*t)*Rot)^ex.m)*vec0;
            rS.val=vec2mtz(vec(1:NS2))/SABRE.fs;
            rC.val=vec2mtz(vec(NS2+1:NS2+NC2))/SABRE.fc;
            Yts=Amplitudes(rS,ex.SOs);                                
            %Ytc=Amplitudes(rC,ex.SOc);
            for ik = 1:3
                Yout{ik}(it,iRF)=real(Yts(ik));            
            end
        end
    end
end

