% This script helps you to get the FID and the spectrum to know the final state of the spin operators.
% PS: It doesn't change the final state to get the spectrum pulse 0 degree 
%% start %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all; %clear all and delete all previous data
tic
p=LoadPath();
%% Load System %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
System=Load_SABRE_System_Name(5);
ex=Load_SABRE_System(System);

ex.Folder="out\Static_spectrum"+System+"_.mat";
%% kinetic parameters %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ex.fpH = 0.52                             ; % pH2 fraction (1 is 100)
ex.Kd  = 15                               ; % [s^-1] dissociation rate
Concentrationofcomplex   = 4.68           ; % Concentration of complex [mM]     
Concentrationofsubstrate = 41             ; % Concentration of substrate [mM]
n = Concentrationofcomplex/Concentrationofsubstrate ;
ex.Wa  = ex.Kd*n                          ; % [s^-1] association rate

%%  parameters %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ex.B0  = 9.4                  ; % observation magnetic field [T]
ex.t1v = 5e-3                 ;
ex.t2v = 9e-3                 ;
ex.tev = 2                    ;
ex.prebubble = 10             ;

%% calculate pulsed SABRE%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[rS, rC] = get_SABRE_initial_state(1,ex);

%% spectrum parameters
spec.pulse  = pi/2                             ; % excitation pulse [rad]
spec.ph1    = 'Y'  ;
%spec.phrec  = 'X'  ;
spec.B0     = ex.B0                         ; % observation magnetic field [T]
spec.v0_1H  = spec.B0*ex.Sc.gamma{1}/(2*pi) ; % observation frequency, Hz
spec.v0_X   = spec.B0*ex.Sc.gamma{end}/(2*pi) ; % observation frequency, Hz
spec.SW     = 4                          ; % [Hz]
spec.TD     = 1024*8                        ; % spectral width and number of points in FID

%% calculate spectrum
v0               = spec.v0_X                       ;
ppm0             = ex.ppmC(end)                    ; % main frequency and detection frequency in ppm
RegNuc           = [3]                               ;
FWHM             = 0.1                                 ; % full width half maximum
Hc               = 2*pi*HZJij(ex.Sc,ex.ppmC,ex.JC,spec.B0,"full")                     ; 
rC = rC.RotationSuperOperator(spec.pulse,spec.ph1,ex.Sc,RegNuc);
[PPM, FRQ, SPEC] = rC.Spectrum(Hc,ex.Sc,spec.SW,spec.TD,v0,ppm0,RegNuc,FWHM,"-X")    ;
PlotSpec(FRQ,SPEC,[+4000,-4100],'Complex X')                                          ;
rC.ShowOperators(ex.Sc,0.001)
 
% % substrate
v0               = spec.v0_X                       ;
RegNuc           = [1]                              ;
ppm0             = ex.ppmS(1)                             ; % main frequency and detection frequency in ppm
FWHM             = 0.1                                ; % full width half maximum
rS = rS.RotationSuperOperator(spec.pulse,spec.ph1,ex.Ss,RegNuc);
Hs               = 2*pi*HZJij(ex.Ss,ex.ppmS,ex.JS,spec.B0,"full")                     ;
[PPM, FRQ, SPEC] = rS.Spectrum(Hs,ex.Ss,spec.SW,spec.TD,v0,ppm0,RegNuc,FWHM,"-X")    ;
PlotSpec(FRQ,SPEC,[-1,1],'Substrate X')                                                        ;
rS. ShowOperators(ex.Ss,0.0001)
 
% SaveData('Spec.dat',[PPM FRQ],[real(SPEC) imag(SPEC)]);

%% plot spectrum
% types_spec{1}="relative FRQ";
% types_spec{2}="absolute FRQ";
% % "all" "c", "s", "1H", "15N"... "1H_c", "1H_s", "15N_c", "15N_s"
% %plot_spectrum(System,ex,spec,types_spec{2},"all");
% plot_spectrum(System,ex,spec,types_spec{2},"c","spectrum")  ;
% %plot_spectrum(System,ex,spec,types_spec{2},"s")  ;
% %plot_spectrum(System,ex,spec,types_spec{2},"15N");
% %plot_4spectra(System,ex,spec,types_spec{2},"all");


%%%%%%%%%%%%%%%%%%%%%%%%%% end %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
toc
